@@ -19,7 +19,7 @@
 # 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA. 
 
 import os, sys, string, shutil
-import wx, time
+import wx, time, shlex
 #from subprocess import Popen,PIPE
 
 import wine_versions
@@ -28,7 +28,6 @@ import lib.wine as wine
 import lib.Variables as Variables
 import lib.lng as lng
 
-
 class Onglets(wx.Notebook):
 	# Classe dérivée du wx.Notebook
 	def __init__(self, parent):
@@ -51,7 +50,11 @@ class Onglets(wx.Notebook):
 		
 	def evt_winecfg(self, event):
 		self.winebash("winecfg")
-		
+
+	def evt_uninstall(self, event):
+		wx.MessageBox(_("Warning:\n\nThis tool is for advanced users.\nTo uninstall cleanly a program with {0}, you must delete the virtual drive associated").format(os.environ["APPLICATION_TITLE"]),os.environ["APPLICATION_TITLE"])
+		self.winebash("uninstaller")
+			
 	def evt_regedit(self, event):
 		self.winebash("regedit")
 
@@ -60,7 +63,14 @@ class Onglets(wx.Notebook):
 
 	def evt_taskmgr(self, event):
 		self.winebash("taskmgr")
-		
+
+	def evt_rep(self, event):
+		try:
+			os.remove(os.environ["POL_USER_ROOT"]+"/wineprefix/"+self.s_prefix+"/.update-timestamp")
+		except:
+			pass
+		self.winebash("wineboot")
+					
 	def evt_wineboot(self, event):
 		self.winebash("wineboot")
 
@@ -81,19 +91,26 @@ class Onglets(wx.Notebook):
 					
 	def AddGeneralChamp(self, title, shortname, value, num):
 		self.general_elements[shortname+"_text"] = wx.StaticText(self.panelGeneral, -1, title,pos=(15,19+num*40))
-		self.general_elements[shortname] = wx.TextCtrl(self.panelGeneral, 200+num, value, pos=(300,19+num*40), size=(150,20))
+		self.general_elements[shortname] = wx.TextCtrl(self.panelGeneral, 200+num, value, pos=(300,23+num*40), size=(250,20))
 	#	self.general_elements[shortname].SetValue(value)
 
 	def AddGeneralElement(self, title, shortname, elements, wine, num):
 		if(shortname == "wineversion"):
 			elements.insert(0,"System")
 			wine.insert(0,"System")
+			elemsize = (225,25)
+		else:
+			elemsize = (250,25)
+			
 		self.general_elements[shortname+"_text"] = wx.StaticText(self.panelGeneral, -1, title,pos=(15,19+num*40))
 		
-		self.general_elements[shortname] = wx.ComboBox(self.panelGeneral, 200+num, style=wx.CB_READONLY,pos=(300,15+num*40))
+		self.general_elements[shortname] = wx.ComboBox(self.panelGeneral, 200+num, style=wx.CB_READONLY,pos=(300,17+num*40),size=elemsize)
 		self.general_elements[shortname].AppendItems(elements)
 		self.general_elements[shortname].SetValue(elements[0])
 
+		if(shortname == "wineversion"):
+			self.addBitmap = wx.Image( Variables.playonlinux_env+"/resources/images/icones/list-add.png", wx.BITMAP_TYPE_ANY).ConvertToBitmap()
+			self.general_elements["wineversion_button"] = wx.BitmapButton(self.panelGeneral,601, pos=(527,19+num*40),size=(21,21),bitmap=self.addBitmap	)
 
 	
 	def General(self, nom):
@@ -119,24 +136,20 @@ class Onglets(wx.Notebook):
 		self.general_elements["debug_text"] = wx.StaticText(self.panelGeneral, -1, _("Enable debugging") ,pos=(15,19+5*40))
 		self.general_elements["debug_check"] = wx.CheckBox(self.panelGeneral, 205, pos=(300,20+5*40))
 	
+		self.AddGeneralChamp(_("Arguments"),"arguments","",6)
 		
-		self.configurator_title = wx.StaticText(self.panelGeneral, -1, "", (10,254), wx.DefaultSize)
+		self.configurator_title = wx.StaticText(self.panelGeneral, -1, "", (10,294), wx.DefaultSize)
 		self.configurator_title.SetFont(self.fontTitle)
-		self.configurator_button = wx.Button(self.panelGeneral, 106, _("Run configuration wizard"), pos=(15,284))
+		self.configurator_button = wx.Button(self.panelGeneral, 106, _("Run configuration wizard"), pos=(15,324))
 		
 		
-		wx.EVT_BUTTON(self, 100, self.evt_winecfg)
-		wx.EVT_BUTTON(self, 101, self.evt_regedit)
-		wx.EVT_BUTTON(self, 102, self.evt_wineboot)
-		wx.EVT_BUTTON(self, 103, self.evt_cmd)
-		wx.EVT_BUTTON(self, 104, self.evt_taskmgr)
-		wx.EVT_BUTTON(self, 105, self.evt_killall)
-		wx.EVT_BUTTON(self, 106, self.evt_config)
-		
 		wx.EVT_TEXT(self, 202, self.setname)
+		wx.EVT_TEXT(self, 206, self.setargs)
+		
 		wx.EVT_COMBOBOX(self, 203, self.assign)
 		wx.EVT_COMBOBOX(self, 204, self.assignPrefix)
 		wx.EVT_CHECKBOX(self, 205, self.setDebug)
+		wx.EVT_BUTTON(self, 601, self.Parent.Parent.Parent.WineVersion)
 		
 	def Wine(self, nom):
 		self.panelWine = wx.Panel(self, -1)
@@ -145,43 +158,69 @@ class Onglets(wx.Notebook):
 		self.txtGeneral = wx.StaticText(self.panelWine, -1, "Wine", (10,10), wx.DefaultSize)
 		self.txtGeneral.SetFont(self.fontTitle)
 
-		self.winecfg_image = wx.Image( Variables.playonlinux_env+"/resources/images/configure/winecfg.png", wx.BITMAP_TYPE_ANY).ConvertToBitmap()
+		self.winecfg_image = wx.Image( Variables.playonlinux_env+"/resources/images/configure/wine-winecfg.png", wx.BITMAP_TYPE_ANY).ConvertToBitmap()
 		self.winecfg = wx.BitmapButton(self.panelWine, id=100, bitmap=self.winecfg_image,pos=(30, 50), size = (self.winecfg_image.GetWidth()+5, self.winecfg_image.GetHeight()+5))
-		self.winecfg_texte = wx.StaticText(self.panelWine, -1, _("Configure Wine"), (30,156), (115,30),wx.ALIGN_CENTER)
+		self.winecfg_texte = wx.StaticText(self.panelWine, -1, _("Configure Wine"), (32,156), style=wx.ALIGN_CENTER)
 		self.winecfg_texte.Wrap(110)
+		self.winecfg_texte.SetPosition((self.winecfg_texte.GetPosition()[0]+(105-self.winecfg_texte.GetSize()[0])/2,self.winecfg_texte.GetPosition()[1]))
+
 		self.winecfg_texte.SetFont(self.caption_font)
 
-		self.regedit_image = wx.Image( Variables.playonlinux_env+"/resources/images/configure/regedit.png", wx.BITMAP_TYPE_ANY).ConvertToBitmap()
+		self.regedit_image = wx.Image( Variables.playonlinux_env+"/resources/images/configure/registry.png", wx.BITMAP_TYPE_ANY).ConvertToBitmap()
 		self.regedit = wx.BitmapButton(self.panelWine, id=101, bitmap=self.regedit_image,pos=(166, 50), size = (self.regedit_image.GetWidth()+5, self.regedit_image.GetHeight()+5))
-		self.regedit_texte = wx.StaticText(self.panelWine, -1, _("Registry Editor"), (166,156), (115,30),wx.ALIGN_CENTER)
+		self.regedit_texte = wx.StaticText(self.panelWine, -1, _("Registry Editor"), (168,156), style=wx.ALIGN_CENTER)
 		self.regedit_texte.Wrap(110)
+		self.regedit_texte.SetPosition((self.regedit_texte.GetPosition()[0]+(105-self.regedit_texte.GetSize()[0])/2,self.regedit_texte.GetPosition()[1]))
+
 		self.regedit_texte.SetFont(self.caption_font)
 
 
-		self.wineboot_image = wx.Image( Variables.playonlinux_env+"/resources/images/configure/wineboot.png", wx.BITMAP_TYPE_ANY).ConvertToBitmap()
+		self.wineboot_image = wx.Image( Variables.playonlinux_env+"/resources/images/configure/reboot.png", wx.BITMAP_TYPE_ANY).ConvertToBitmap()
 		self.wineboot = wx.BitmapButton(self.panelWine, id=102, bitmap=self.wineboot_image,pos=(302, 50), size = (self.wineboot_image.GetWidth()+5, self.wineboot_image.GetHeight()+5))		
-		self.wineboot_texte = wx.StaticText(self.panelWine, -1, _("Windows reboot"), (302,156), (130,30),wx.ALIGN_CENTER)
+		self.wineboot_texte = wx.StaticText(self.panelWine, -1, _("Windows reboot"), (304,156), style=wx.ALIGN_CENTER)
 		self.wineboot_texte.Wrap(110)
+		self.wineboot_texte.SetPosition((self.wineboot_texte.GetPosition()[0]+(105-self.wineboot_texte.GetSize()[0])/2,self.wineboot_texte.GetPosition()[1]))
 		self.wineboot_texte.SetFont(self.caption_font)
-
-		self.cmd_image = wx.Image( Variables.playonlinux_env+"/resources/images/configure/cmd.png", wx.BITMAP_TYPE_ANY).ConvertToBitmap()
+		
+		
+		self.updatep_image = wx.Image( Variables.playonlinux_env+"/resources/images/configure/update.png", wx.BITMAP_TYPE_ANY).ConvertToBitmap()
+		self.updatep = wx.BitmapButton(self.panelWine, id=107, bitmap=self.updatep_image,pos=(438, 50), size = (self.wineboot_image.GetWidth()+5, self.updatep_image.GetHeight()+5))		
+		self.updatep_texte = wx.StaticText(self.panelWine, -1, _("Repair virtual drive"), (440,156), style=wx.ALIGN_CENTER)
+		self.updatep_texte.Wrap(110)
+		self.updatep_texte.SetPosition((self.updatep_texte.GetPosition()[0]+(105-self.wineboot_texte.GetSize()[0])/2,self.updatep_texte.GetPosition()[1]))
+		self.updatep_texte.SetFont(self.caption_font)
+		
+		
+	
+		self.cmd_image = wx.Image( Variables.playonlinux_env+"/resources/images/configure/console.png", wx.BITMAP_TYPE_ANY).ConvertToBitmap()
 		self.cmd = wx.BitmapButton(self.panelWine, id=103, bitmap=self.cmd_image,pos=(30, 196), size = (self.cmd_image.GetWidth()+5, self.cmd_image.GetHeight()+5))
-		self.cmd_texte = wx.StaticText(self.panelWine, -1, _("Command prompt"), (30,302), (115,30),wx.ALIGN_CENTER)
-		self.cmd_texte.Wrap(115)
+		self.cmd_texte = wx.StaticText(self.panelWine, -1, _("Command prompt"), (32,302), style=wx.ALIGN_CENTER)
+		self.cmd_texte.Wrap(110)
+		self.cmd_texte.SetPosition((self.cmd_texte.GetPosition()[0]+(105-self.cmd_texte.GetSize()[0])/2,self.cmd_texte.GetPosition()[1]))
 		self.cmd_texte.SetFont(self.caption_font)
 
-		self.taskmgr_image = wx.Image( Variables.playonlinux_env+"/resources/images/configure/taskmgr.png", wx.BITMAP_TYPE_ANY).ConvertToBitmap()
+		self.taskmgr_image = wx.Image( Variables.playonlinux_env+"/resources/images/configure/monitor.png", wx.BITMAP_TYPE_ANY).ConvertToBitmap()
 		self.taskmgr = wx.BitmapButton(self.panelWine, id=104, bitmap=self.taskmgr_image,pos=(166, 196), size = (self.taskmgr_image.GetWidth()+5, self.taskmgr_image.GetHeight()+5))
-		self.taskmgr_texte = wx.StaticText(self.panelWine, -1, _("Task manager"), (166,302), (115,30),wx.ALIGN_CENTER)
+		self.taskmgr_texte = wx.StaticText(self.panelWine, -1, _("Task manager"), (168,302), style=wx.ALIGN_CENTER)
 		self.taskmgr_texte.Wrap(110)
+		self.taskmgr_texte.SetPosition((self.taskmgr_texte.GetPosition()[0]+(105-self.taskmgr_texte.GetSize()[0])/2,self.taskmgr_texte.GetPosition()[1]))
+		
 		self.taskmgr_texte.SetFont(self.caption_font)
 
-		self.killall_image = wx.Image( Variables.playonlinux_env+"/resources/images/configure/killall.png", wx.BITMAP_TYPE_ANY).ConvertToBitmap()
+		self.killall_image = wx.Image( Variables.playonlinux_env+"/resources/images/configure/stop.png", wx.BITMAP_TYPE_ANY).ConvertToBitmap()
 		self.killall = wx.BitmapButton(self.panelWine, id=105, bitmap=self.killall_image,pos=(302, 196), size = (self.killall_image.GetWidth()+5, self.killall_image.GetHeight()+5))		
-		self.killall_texte = wx.StaticText(self.panelWine, -1, _("Kill processes"), (302,302), (130,30),wx.ALIGN_CENTER)
+		self.killall_texte = wx.StaticText(self.panelWine, -1, _("Kill processes"), (304,302), style=wx.ALIGN_CENTER)
 		self.killall_texte.Wrap(110)
+		self.killall_texte.SetPosition((self.killall_texte.GetPosition()[0]+(105-self.killall_texte.GetSize()[0])/2,self.killall_texte.GetPosition()[1]))
 		self.killall_texte.SetFont(self.caption_font)
 
+		self.uninstall_image = wx.Image( Variables.playonlinux_env+"/resources/images/configure/wine-uninstaller.png", wx.BITMAP_TYPE_ANY).ConvertToBitmap()
+		self.uninstall = wx.BitmapButton(self.panelWine, id=108, bitmap=self.uninstall_image,pos=(438, 196), size = (self.wineboot_image.GetWidth()+5, self.uninstall_image.GetHeight()+5))		
+		self.uninstall_texte = wx.StaticText(self.panelWine, -1, _("Wine uninstaller"), (440,302), style=wx.ALIGN_CENTER)
+		self.uninstall_texte.Wrap(110)
+		self.uninstall_texte.SetPosition((self.uninstall_texte.GetPosition()[0]+(105-self.wineboot_texte.GetSize()[0])/2,self.uninstall_texte.GetPosition()[1]))
+		self.uninstall_texte.SetFont(self.caption_font)
+
 
 		wx.EVT_BUTTON(self, 100, self.evt_winecfg)
 		wx.EVT_BUTTON(self, 101, self.evt_regedit)
@@ -190,6 +229,8 @@ class Onglets(wx.Notebook):
 		wx.EVT_BUTTON(self, 104, self.evt_taskmgr)
 		wx.EVT_BUTTON(self, 105, self.evt_killall)
 		wx.EVT_BUTTON(self, 106, self.evt_config)
+		wx.EVT_BUTTON(self, 107, self.evt_rep)
+		wx.EVT_BUTTON(self, 108, self.evt_uninstall)
 
 				
 	def Packages(self, nom):
@@ -197,7 +238,7 @@ class Onglets(wx.Notebook):
 		self.txtPackages = wx.StaticText(self.panelPackages, -1, _(nom), (10,10), wx.DefaultSize)
 		self.txtPackages.SetFont(self.fontTitle)
 
-		self.Menu = wx.ListBox(self.panelPackages, 99, pos=(15,45),size=(430,235), style=Variables.widget_borders)
+		self.Menu = wx.ListBox(self.panelPackages, 99, pos=(15,45),size=(530,235), style=Variables.widget_borders)
 		self.PackageButton = wx.Button(self.panelPackages, 98, _("Install"), pos=(10,295))
 		
 		try : 
@@ -243,7 +284,7 @@ class Onglets(wx.Notebook):
 	def UpdateVersions(self, arch):
 		elements = playonlinux.Get_versions(arch)
 		self.general_elements["wineversion"].Clear()
-		if(arch == 'x86'):
+		if(arch == playonlinux.GetSettings("WINE_SYSTEM_ARCH") or (arch == "x86" and playonlinux.GetSettings("WINE_SYSTEM_ARCH") != "amd64")):
 			self.general_elements["wineversion"].Append("System")
 		self.general_elements["wineversion"].AppendItems(elements)
 		version = playonlinux.GetSettings('VERSION',self.s_prefix)
@@ -259,6 +300,9 @@ class Onglets(wx.Notebook):
 			#self.general_elements["wineversion"].SetValue(wine_versions.GetWineVersion(selection))
 			#self.general_elements["wineversion"].Show()
 			self.general_elements["wineprefix"].Show()
+			self.general_elements["arguments"].Show()
+			self.general_elements["arguments_text"].Show()
+			
 			#self.general_elements["name"].Show()
 			#self.general_elements["wineversion_text"].Show()
 			self.general_elements["wineprefix_text"].Show()
@@ -268,6 +312,8 @@ class Onglets(wx.Notebook):
 			
 			#self.general_elements["name_text"].Show()
 			self.general_elements["wineprefix"].SetValue(playonlinux.getPrefix(self.s_title))
+			self.general_elements["arguments"].SetValue(playonlinux.getArgs(self.s_title))
+			
 			self.display_elements["folder_button"].SetLabel(_("Open program's directory"))
 			self.general_elements["debug_check"].SetValue(playonlinux.GetDebugState(self.s_title))
 			if(os.path.exists(Variables.playonlinux_rep+"configurations/configurators/"+self.s_title)):
@@ -276,8 +322,9 @@ class Onglets(wx.Notebook):
 			else:
 				self.configurator_title.Hide()
 				self.configurator_button.Hide()
-			self.configurator_title.SetLabel(self.s_title+" specific configuration")
-				
+			self.configurator_title.SetLabel("{0} specific configuration".format(self.s_title))
+			self.display_elements["pre_run_panel"].Show()
+			self.display_elements["pre_run_text"].Show()
 		else:
 			self.s_prefix = selection
 			self.s_title = selection
@@ -286,7 +333,8 @@ class Onglets(wx.Notebook):
 			#self.general_elements["name"].Hide()
 			self.general_elements["name"].SetEditable(False)
 			self.general_elements["name"].SetValue(self.s_prefix)
-			
+			self.general_elements["arguments"].Hide()
+			self.general_elements["arguments_text"].Hide()			
 			#self.general_elements["wineversion_text"].Hide()
 			self.general_elements["wineprefix_text"].Hide()
 			self.general_elements["debug_text"].Hide()
@@ -295,7 +343,9 @@ class Onglets(wx.Notebook):
 			self.display_elements["folder_button"].SetLabel(_("Open virtual drive's directory"))
 			self.configurator_title.Hide()
 			self.configurator_button.Hide()
-		
+			self.display_elements["pre_run_panel"].Hide()
+			self.display_elements["pre_run_text"].Hide()
+			
 		self.Refresh()
 		self.elements = ["UseGLSL","DirectDrawRenderer","VideoMemorySize","OffscreenRenderingMode","RenderTargetModeLock","Multisampling","StrictDrawOrdering","MouseWarpOverride"]
 		self.settings = wine.LoadRegValues(self.s_prefix,self.elements)
@@ -308,13 +358,17 @@ class Onglets(wx.Notebook):
 		self.get_current_settings("Multisampling")
 		self.get_current_settings("StrictDrawOrdering")
 		self.get_current_settings("MouseWarpOverride")
-
+		
 		self.arch = playonlinux.GetSettings('ARCH',self.s_prefix)
 		if(self.arch == ""):
 			self.arch = "x86"
 			
 		self.UpdateVersions(self.arch)
-		
+		try:
+			self.display_elements["pre_run"].SetValue(open(os.environ["POL_USER_ROOT"]+"/configurations/pre_shortcut/"+self.s_title,'r').read())
+		except:
+			self.display_elements["pre_run"].SetValue("")
+			
 			
 	def change_settings(self, event):
 		param = event.GetId()
@@ -358,9 +412,9 @@ class Onglets(wx.Notebook):
 			self.FileDialog.ShowModal()
 			if(self.FileDialog.GetPath() != ""):
 				if(self.s_isPrefix == True):
-					os.system("bash "+Variables.playonlinux_env+"/bash/POL_Command --prefix \""+self.s_prefix+"\" POL_AutoWine \""+self.FileDialog.GetPath().encode('utf-8')+"\" &")
+					os.system("bash "+Variables.playonlinux_env+"/bash/POL_Command --prefix \""+self.s_prefix+"\" POL_AutoWine \""+self.FileDialog.GetPath().encode("utf-8","replace")+"\" &")
 				else:
-					os.system("bash "+Variables.playonlinux_env+"/bash/POL_Command \""+self.s_title+"\" POL_AutoWine \""+self.FileDialog.GetPath().encode('utf-8')+"\" &")
+					os.system("bash "+Variables.playonlinux_env+"/bash/POL_Command \""+self.s_title+"\" POL_AutoWine \""+self.FileDialog.GetPath().encode("utf-8","replace")+"\" &")
 					
 		if(param == 201):
 			if(self.s_isPrefix == False):
@@ -371,9 +425,10 @@ class Onglets(wx.Notebook):
 	def AddDisplayElement(self, title, shortname, elements, wine, num):
 		elements.insert(0,"Default")
 		wine.insert(0,"default")
+		elemsize = (230,25)
 		self.display_elements[shortname+"_text"] = wx.StaticText(self.panelDisplay, -1, title,pos=(15,19+num*40))
 		
-		self.display_elements[shortname] = wx.ComboBox(self.panelDisplay, 300+num, style=wx.CB_READONLY,pos=(300,15+num*40))
+		self.display_elements[shortname] = wx.ComboBox(self.panelDisplay, 300+num, style=wx.CB_READONLY,pos=(300,17+num*40),size=elemsize)
 		self.display_elements[shortname].AppendItems(wine)
 		self.display_elements[shortname].SetValue(wine[0])
 		wx.EVT_COMBOBOX(self, 300+num,  self.change_settings)
@@ -382,21 +437,38 @@ class Onglets(wx.Notebook):
 	def AddMiscElement(self, title, shortname, elements, wine, num):
 		elements.insert(0,"Default")
 		wine.insert(0,"default")
+		elemsize = (230,25)
 		self.display_elements[shortname+"_text"] = wx.StaticText(self.panelMisc, -1, title,pos=(15,19+num*40))
 
-		self.display_elements[shortname] = wx.ComboBox(self.panelMisc, 400+num, style=wx.CB_READONLY,pos=(300,15+num*40))
+		self.display_elements[shortname] = wx.ComboBox(self.panelMisc, 400+num, style=wx.CB_READONLY,pos=(300,17+num*40),size=elemsize)
 		self.display_elements[shortname].AppendItems(wine)
 		self.display_elements[shortname].SetValue(wine[0])
 		wx.EVT_COMBOBOX(self, 400+num,  self.change_settings)
 
 	def AddMiscButton(self, title, shortname, num):
-		self.display_elements[shortname+"_button"] = wx.Button(self.panelMisc, 400+num, "",pos=(15,19+num*40),size=(400,30))
+		self.display_elements[shortname+"_button"] = wx.Button(self.panelMisc, 400+num, "",pos=(15,19+num*40),size=(500,30))
 		self.display_elements[shortname+"_button"].SetLabel(title)
 		
 		wx.EVT_BUTTON(self, 400+num,  self.misc_button)
-
+		
+	def AddMiscLongText(self, title, shortname, num):
+		self.display_elements[shortname+"_text"] = wx.StaticText(self.panelMisc, -1, title,pos=(15,19+num*40))
+		self.display_elements[shortname+"_panel"] = wx.Panel(self.panelMisc, -1, size=wx.Size(450,70),pos=(20,44+num*40))
+		
+		try: 
+			content = open(os.environ["POL_USER_ROOT"]+"/configurations/pre_shortcut/"+self.s_title,'r').read()
+		except:
+			content = ""
+		
+		self.display_elements[shortname] = wx.TextCtrl(self.display_elements[shortname+"_panel"], 400+num, content, size=wx.Size(448,68), pos=(2,2), style=Variables.widget_borders|wx.TE_MULTILINE)
+		wx.EVT_TEXT(self, 405,  self.edit_shortcut)
+		
+	def edit_shortcut(self, event):
+		content = self.display_elements["pre_run"].GetValue().encode("utf-8","replace")
+		open(os.environ["POL_USER_ROOT"]+"/configurations/pre_shortcut/"+self.s_title,'w').write(content)
+		
 	def AddGeneralButton(self, title, shortname, num):
-		self.general_elements[shortname+"_button"] = wx.Button(self.panelGeneral, 200+num, "",pos=(15,9+num*40),size=(400,30))
+		self.general_elements[shortname+"_button"] = wx.Button(self.panelGeneral, 200+num, "",pos=(15,9+num*40),size=(520,30))
 		self.general_elements[shortname+"_button"].SetLabel(title)
 
 		wx.EVT_BUTTON(self, 200+num,  self.misc_button)
@@ -429,6 +501,7 @@ class Onglets(wx.Notebook):
 		self.AddMiscButton("","folder",2)
 		self.AddMiscButton(_("Open a shell"),"shell",3)
 		self.AddMiscButton(_("Run a .exe file in this virtual drive"),"exerun",4)
+		self.AddMiscLongText(_("Command to exec before running the program"),"pre_run",5)
 		
 		self.AddPage(self.panelMisc, nom)
 		
@@ -439,11 +512,19 @@ class Onglets(wx.Notebook):
 		else:
 			playonlinux.DeleteSettings('VERSION',self.s_prefix)
 	def assignPrefix(self, event):
-		drive = self.general_elements["wineprefix"].GetValue()
-		playonlinux.SetWinePrefix(self.s_title, drive)
+		if(wx.YES == wx.MessageBox(_("Be careful!\nIf you change "+self.s_title+"'s virtual drive, you are likekely to break it.\nDo this only if you know what you are doing.\n\nAre you sure you want to continue?"),os.environ["APPLICATION_TITLE"] ,style=wx.YES_NO | wx.ICON_QUESTION)):
+			drive = self.general_elements["wineprefix"].GetValue()
+			playonlinux.SetWinePrefix(self.s_title, drive)
+		else:
+			self.general_elements["wineprefix"].SetValue(self.s_prefix)
 	
 	def ReleaseTyping(self, event):
 		self.typing = False
+
+	def setargs(self, event):
+		new_args = self.general_elements["arguments"].GetValue()
+		playonlinux.writeArgs(self.s_title, new_args)
+
 				
 	def setname(self, event):
 		new_name = self.general_elements["name"].GetValue()
@@ -486,15 +567,20 @@ class Onglets(wx.Notebook):
 	
 class MainWindow(wx.Frame):
 	def __init__(self,parent,id,title,shortcut, isPrefix = False):
-		wx.Frame.__init__(self, parent, -1, title, size = (700, 450), style = wx.CLOSE_BOX | wx.CAPTION | wx.MINIMIZE_BOX)
+		wx.Frame.__init__(self, parent, -1, title, size = (800, 450), style = wx.CLOSE_BOX | wx.CAPTION | wx.MINIMIZE_BOX)
 		self.SetIcon(wx.Icon(Variables.playonlinux_env+"/etc/playonlinux.png", wx.BITMAP_TYPE_ANY))
 		self.SetTitle(_('{0} configuration').format(os.environ["APPLICATION_TITLE"]))
 		#self.panelFenp = wx.Panel(self, -1)
 	
 		self.splitter = wx.SplitterWindow(self, -1, style=wx.SP_NOBORDER)
 		
+		self.panelEmpty = wx.Panel(self.splitter, -1)
 		self.onglets = Onglets(self.splitter)
 		
+		self.noselect = wx.StaticText(self.panelEmpty, -1, _('Please select a program or a virtual drive to configure'),pos=(0,150),style=wx.ALIGN_RIGHT)
+		self.noselect.SetPosition(((600-self.noselect.GetSize()[0])/2,150))
+		
+		self.noselect.Wrap(600)
 		if(isPrefix == True):
 			self.onglets.s_isPrefix = True
 			self.onglets.s_prefix = shortcut
@@ -522,7 +608,8 @@ class MainWindow(wx.Frame):
 		self.list_game.SetSpacing(0);
 		self.list_game.SetImageList(self.images)
 		
-		self.splitter.SplitVertically(self.splitter_list,self.onglets)
+	
+		self.splitter.SplitVertically(self.splitter_list,self.panelEmpty)
 		self.splitter.SetSashPosition(200)
 	
 		self.onglets.General(_("General"))
@@ -534,35 +621,39 @@ class MainWindow(wx.Frame):
 		self.list_software()
 
 		self.onglets.panelGeneral.Bind(wx.EVT_LEFT_UP, self.onglets.ReleaseTyping)
-		
 		wx.EVT_TREE_SEL_CHANGED(self, 900, self.change_program_to_selection)
 		#self.change_program(shortcut,isPrefix)
 		
 		self.timer = wx.Timer(self, 1)
 		self.Bind(wx.EVT_TIMER, self.AutoReload, self.timer)
-		self.timer.Start(1000)
+		
+		self.timer.Start(200)
 		self.oldreload = None
 		self.oldimg = None
 		self.oldpref = None
+		self.oldver32 = None
+		self.olderver64 = None
+		#if(self.onglets.s_isPrefix == False or not self.onglets.s_prefix == "default"):
+		self.AutoReload(self)
 	
 	def NewPrefix(self, event):
-		self.name = wx.GetTextFromUser(_("Choose the name of the virtual drive"))
-		if(self.name != ""):
-			os.system("bash "+Variables.playonlinux_env+"/bash/POL_Command --init --prefix \""+self.name+"\" POL_SetupWindow_prefixcreate &")
+		#self.name = wx.GetTextFromUser(_("Choose the name of the virtual drive"))
+		#if(self.name != ""):
+		os.system("bash "+Variables.playonlinux_env+"/bash/create_prefix &")
 			
 	def DeletePrefix(self, event):
 		if(self.onglets.s_isPrefix == True):
 			if(self.onglets.s_prefix == "default"):
-				wx.MessageBox(_("This virtual drive is protected"))
+				wx.MessageBox(_("This virtual drive is protected"), os.environ["APPLICATION_TITLE"])
 			else:
-				if(wx.YES == wx.MessageBox(_("Are you sure you want to delete "+self.onglets.s_prefix.encode("utf-8")+" virtual drive ?").decode("utf-8"), style=wx.YES_NO | wx.ICON_QUESTION)):
+				if(wx.YES == wx.MessageBox(_("Are you sure you want to delete {0} virtual drive ?").format(self.onglets.s_prefix.encode("utf-8","replace")).decode("utf-8","replace"), os.environ["APPLICATION_TITLE"], style=wx.YES_NO | wx.ICON_QUESTION)):
 					mylist = os.listdir(Variables.playonlinux_rep+"/shortcuts")
 					for element in mylist:
 						if(playonlinux.getPrefix(element).lower() == self.onglets.s_prefix.lower()):
 							os.remove(Variables.playonlinux_rep+"/shortcuts/"+element)
 					shutil.rmtree(Variables.playonlinux_rep+"/wineprefix/"+self.onglets.s_prefix)
 		else:
-				if(wx.YES == wx.MessageBox(_("Are you sure you want to delete "+self.onglets.s_title.encode("utf-8")+" ?").decode("utf-8"), style=wx.YES_NO | wx.ICON_QUESTION)):
+				if(wx.YES == wx.MessageBox(_("Are you sure you want to delete {0} ?").format(self.onglets.s_title.encode("utf-8","replace")).decode("utf-8","replace"), os.environ["APPLICATION_TITLE"], style=wx.YES_NO | wx.ICON_QUESTION)):
 					os.remove(Variables.playonlinux_rep+"/shortcuts/"+self.onglets.s_title)
 					
 		self.onglets.s_isPrefix = True
@@ -587,21 +678,49 @@ class MainWindow(wx.Frame):
 				self.list_software()
 				self.oldpref = reloadpref
 			
+			reloadver32 = os.listdir(Variables.playonlinux_rep+"/wine/"+Variables.os_name+"-x86/")
+			reloadver64 = os.listdir(Variables.playonlinux_rep+"/wine/"+Variables.os_name+"-amd64/")
+			 
+			if(reloadver32 != self.oldver32 or reloadver64 != self.oldver64):
+				self.oldver32 = reloadver32
+				self.oldver64 = reloadver64
+				self.onglets.UpdateVersions(self.onglets.arch)
+				
 	def change_program_to_selection(self, event):
 		parent =  self.list_game.GetItemText(self.list_game.GetItemParent(self.list_game.GetSelection()))
+		self.current_sel = self.list_game.GetItemText(self.list_game.GetSelection())
+		
 		if(parent == "#ROOT#"):
 			self.onglets.s_isPrefix = True
 		else:
 			self.onglets.s_isPrefix = False
 		
-		self.change_program(self.list_game.GetItemText(self.list_game.GetSelection()),self.onglets.s_isPrefix)
+		self.change_program(self.current_sel,self.onglets.s_isPrefix)
 		
 	def change_program(self, new_prgm,isPrefix = False):
 		self.onglets.changing_selection = True
 		if(isPrefix == True):
 			self.onglets.s_isPrefix = True
+			if(self.current_sel == "default"):
+				self.splitter.Unsplit()
+				self.splitter.SplitVertically(self.splitter_list,self.panelEmpty)
+				self.splitter.SetSashPosition(200)
+			else:
+				self.splitter.Unsplit()
+				self.splitter.SplitVertically(self.splitter_list,self.onglets)
+				self.splitter.SetSashPosition(200)
+		else:
+			self.splitter.Unsplit()
+			self.splitter.SplitVertically(self.splitter_list,self.onglets)
+			self.splitter.SetSashPosition(200)
 		self.onglets.UpdateValues(new_prgm)
-	
+		self.Refresh()
+		self.SetFocus()
+		try:
+			self.GetTopWindow().Raise()
+		except:
+			pass
+			
 	def list_software(self):
 		self.games = os.listdir(Variables.playonlinux_rep+"shortcuts/")
 		self.games.sort()
@@ -634,7 +753,15 @@ class MainWindow(wx.Frame):
 				if(os.path.exists(Variables.playonlinux_rep+"/wineprefix/"+prefix+"/icon")):
 					self.file_icone = Variables.playonlinux_rep+"/wineprefix/"+prefix+"/icon"
 				else:
-					self.file_icone = Variables.playonlinux_env+"/resources/images/menu/prefix-manager.png"
+					try:
+						archdd = playonlinux.GetSettings('ARCH',prefix)
+						if(archdd == "amd64"):
+							archdd = "64"
+						else:
+							archdd = "32"
+					except:
+						archdd = "32"
+					self.file_icone = Variables.playonlinux_env+"/resources/images/menu/virtual_drive_"+archdd+".png"
 
 				try:
 					self.bitmap = wx.Image(self.file_icone)
@@ -666,12 +793,16 @@ class MainWindow(wx.Frame):
 				self.i += 1
 
 		self.list_game.ExpandAll()
-		
-		if(self.onglets.s_isPrefix == True):
-			self.list_game.SelectItem(self.prefixes_item[self.onglets.s_prefix.encode("utf-8")])
-		else:
-			self.list_game.SelectItem(self.games_item[self.onglets.s_title.encode("utf-8")])
-	
+		try:
+			if(self.onglets.s_isPrefix == True):
+				self.list_game.SelectItem(self.prefixes_item[self.onglets.s_prefix.encode("utf-8","replace")])
+			else:
+				self.list_game.SelectItem(self.games_item[self.onglets.s_title.encode("utf-8","replace")])
+		except:
+			self.onglets.s_isPrefix = True
+			self.change_program("default",True)
+			self.list_game.SelectItem(self.prefixes_item["default"])
+			
 	def app_Close(self, event):
 		self.Destroy()
 
