@@ -23,6 +23,7 @@ import wx, os, getopt, sys, urllib, signal, time, string, urlparse, codecs, time
 from subprocess import Popen,PIPE
 import lib.Variables as Variables
 import lib.lng
+import lib.DirTreeCtrl as DirTreeCtrl
 lib.lng.Lang()
 
 class Download(threading.Thread):
@@ -54,7 +55,7 @@ class Download(threading.Thread):
 	
 
 class POL_SetupFrame(wx.Frame): #fenêtre principale
-	def __init__(self, titre, POL_SetupWindowID, Arg1, Arg2, bash_pid):
+	def __init__(self, titre, POL_SetupWindowID, Arg1, Arg2, Arg3, bash_pid):
 		wx.Frame.__init__(self, None, -1, title = titre, style = wx.CLOSE_BOX | wx.CAPTION | wx.MINIMIZE_BOX, size = (520, 398+Variables.windows_add_size))
 
 		self.SetIcon(wx.Icon(Variables.playonlinux_env+"/etc/playonlinux.png", wx.BITMAP_TYPE_ANY))
@@ -62,6 +63,7 @@ class POL_SetupFrame(wx.Frame): #fenêtre principale
 		self.fichier = ""
 		self.last_time = int(round(time.time() * 1000))
 		self.downloading = False
+		self.ProtectedWindow = False
 		
 		# Le fichier de lecture
 		self.file_id=Variables.playonlinux_rep+"/configurations/guis/"+POL_SetupWindowID
@@ -81,6 +83,8 @@ class POL_SetupFrame(wx.Frame): #fenêtre principale
 		else:
 			self.big_image = wx.Bitmap(Arg2)
 
+		if(Arg3 == "protect"):
+			self.ProtectedWindow = True
 		self.oldfichier = ""
 		self.bash_pid = bash_pid
 		
@@ -123,24 +127,38 @@ class POL_SetupFrame(wx.Frame): #fenêtre principale
 
 		
 		# Text
-		self.titre_header = wx.StaticText(self.header, -1, _('{0} Wizard').format(os.environ["APPLICATION_TITLE"]),pos=(5,5), size=(340,356))
+		self.titre_header = wx.StaticText(self.header, -1, _('{0} Wizard').format(os.environ["APPLICATION_TITLE"]),pos=(5,5), size=(340,356),style=wx.ST_NO_AUTORESIZE)
 		self.titre_header.SetFont(self.fontTitre)
-		self.texte = wx.StaticText(self.panel, -1, "",pos=(20,80),size=(480,275))
-		self.texte_bis = wx.StaticText(self.panel, -1, "",size=(480,30))
-		self.titre = wx.StaticText(self.header, -1, "",pos=(20,30), size=(340,356))
+		self.titre_header.SetForegroundColour((0,0,0)) # For dark themes
+		
+		self.texte = wx.StaticText(self.panel, -1, "",pos=(20,80),size=(480,275),style=wx.ST_NO_AUTORESIZE)
+		self.texte_bis = wx.StaticText(self.panel, -1, "",size=(480,30),style=wx.ST_NO_AUTORESIZE)
+		self.titre = wx.StaticText(self.header, -1, "",pos=(20,30), size=(340,356),style=wx.ST_NO_AUTORESIZE)
+		self.titre.SetForegroundColour((0,0,0)) # For dark themes
+		
 		self.texteP = wx.StaticText(self.MainPanel, -1, "",pos=(5,50))
+		self.texteP.SetForegroundColour((0,0,0)) # For dark themes
+		
 		self.titreP = wx.StaticText(self.MainPanel, -1,"",pos=(5,5), size=(340,356))
 		self.titreP.SetFont(self.fontTitre)
-		self.txtEstimation = wx.StaticText(self.panel, -1, "",size=(480,30))
+		self.titreP.SetForegroundColour((0,0,0)) # For dark themes
 		
+		self.txtEstimation = wx.StaticText(self.panel, -1, "",size=(480,30),style=wx.ST_NO_AUTORESIZE)
+		self.register_link = ""
 		# Buttons
 		self.CancelButton = wx.Button(self.footer, wx.ID_CANCEL, _("Cancel"), pos=(430,0),size=(85,37))
+		if(self.ProtectedWindow == True):
+			self.CancelButton.Enable(False)
+			
 		self.NextButton = wx.Button(self.footer, wx.ID_FORWARD, _("Next"), pos=(340,0),size=(85,37))
 		self.BackButton = wx.Button(self.footer, wx.ID_FORWARD, _("Back"), pos=(250,0),size=(85,37))
 		
 		self.NoButton = wx.Button(self.footer, wx.ID_NO, _("No"), pos=(430,0),size=(85,37))
 		self.YesButton = wx.Button(self.footer, wx.ID_YES, _("Yes"), pos=(340,0), size=(85,37))
 		self.browse = wx.Button(self.panel, 103, _("Browse"), size=(130,25))
+		#self.FileList = DirTreeCtrl(None, -1)
+		
+		#DirTreeCtrl(self.FileList)
 		#self.register = wx.HyperlinkCtrl(self.footer, 305, _("Having "), "", pos=(20,180))
 	
 		# D'autres trucs
@@ -157,6 +175,8 @@ class POL_SetupFrame(wx.Frame): #fenêtre principale
 
 		self.gauge = wx.Gauge(self.panel, -1, 50, size=(375, 20))
 		self.pulsebar = wx.Gauge(self.panel, -1, 50, size=(375, 20))
+		self.WaitButton = wx.Button(self.panel, 310, "", size=(250,25))
+		
 		self.images = wx.ImageList(22, 22)
 		self.MenuGames = wx.TreeCtrl(self.panel, 111, style=wx.TR_HIDE_ROOT|wx.TR_FULL_ROW_HIGHLIGHT|Variables.widget_borders, pos=(25,105),size=(460,220))
 		self.MenuGames.SetImageList(self.images)
@@ -217,6 +237,7 @@ class POL_SetupFrame(wx.Frame): #fenêtre principale
 		self.password.Hide()
 		self.passbox.Hide()
 		self.register.Hide()
+		self.WaitButton.Hide()
 		self.MCheckBox.SetValue(False)
 		self.PCheckBox.SetValue(False)
 		self.Refresh()
@@ -224,10 +245,14 @@ class POL_SetupFrame(wx.Frame): #fenêtre principale
 		
 	def POL_register(self, event):
 		if(os.environ["POL_OS"] == "Mac"): 
-			os.system("open http://www.playonmac.com/en/register.html")
+			os.system("open "+self.register_link)
 		else:
-			os.system("xdg-open http://www.playonlinux.com/en/register.html")
-		
+			os.system("xdg-open "+self.register_link)
+			
+	def RunCommand(self, event, command,confirm):
+		if(confirm == "0" or wx.YES == wx.MessageBox(confirm.decode("utf-8","replace"), os.environ["APPLICATION_TITLE"], style=wx.YES_NO | wx.ICON_QUESTION)):
+			os.system(command+"&");
+			
 	def DrawImage(self):			
 		self.left_image.Show()
 
@@ -277,16 +302,16 @@ class POL_SetupFrame(wx.Frame): #fenêtre principale
 		self.NextButton.Enable(False)
 	
 	def release_login(self, event):
-		self.SendBash("LOGIN="+self.loginbox.GetValue().encode("utf-8")+"\nPASS="+self.passbox.GetValue().encode("utf-8"))
+		self.SendBash("LOGIN="+self.loginbox.GetValue().encode("utf-8","replace")+"\nPASS="+self.passbox.GetValue().encode("utf-8","replace"))
 		self.NextButton.Enable(False)
 
 	def release_champ(self, event):
-		self.SendBash("MSG_VALUE="+self.champ.GetValue().encode("utf-8"))
+		self.SendBash("MSG_VALUE="+self.champ.GetValue().encode("utf-8","replace"))
 		self.NextButton.Enable(False)
 			
 	def release_bigchamp(self, event):
 		self.SendBash("MSG_VALUE=Ok")
-		self.SendBashT(self.bigchamp.GetValue().encode("utf-8"))
+		self.SendBashT(self.bigchamp.GetValue().encode("utf-8","replace"))
 		self.NextButton.Enable(False)
 			
 	def release_menu(self,event):
@@ -294,7 +319,7 @@ class POL_SetupFrame(wx.Frame): #fenêtre principale
 		self.NextButton.Enable(False)
 
 	def release_menu_list(self,event):
-		self.SendBash("MSG_VALUE="+self.MenuList.GetValue())
+		self.SendBash("MSG_VALUE="+self.MenuList.GetValue().encode("utf-8","replace"))
 		self.NextButton.Enable(False)
 
 	def release_menu_num(self,event):
@@ -313,23 +338,32 @@ class POL_SetupFrame(wx.Frame): #fenêtre principale
 		self.NextButton.Enable(False)
 
 	def release_menugame(self,event):
-		self.SendBash("MSG_VALUE="+self.MenuGames.GetItemText(self.MenuGames.GetSelection()).encode("utf-8"))
+		self.SendBash("MSG_VALUE="+self.MenuGames.GetItemText(self.MenuGames.GetSelection()).encode("utf-8","replace"))
 		self.NextButton.Enable(False)
 		
 	def release_menuprefixes(self,event):
 		if(self.PCheckBox.IsChecked() == False): # Alors il faut renvoyer le prefix
-			self.SendBash("MSG_VALUE=1;"+self.MenuGames.GetItemText(self.MenuGames.GetSelection()).encode("utf-8"))
+			self.SendBash("MSG_VALUE=1;"+self.MenuGames.GetItemText(self.MenuGames.GetSelection()).encode("utf-8","replace"))
 		else:
 			self.SendBash("MSG_VALUE=2;"+self.areaList[self.Menu.GetSelection()])
 			
 		self.NextButton.Enable(False)		
 
 	def Cancel(self, event):
-		self.Destroy()
-		self.SendBash("MSG_RECEIVED=Cancel") #Indiquera à PlayOnLinux bash qu'il faut arreter l'installation
-		os.system("kill -9 "+self.bash_pid) # Plus bourrain, mais bien plus efficace
-		os.remove(self.file_id) # La on est plutôt pépère pour faire ça
-		
+		if(self.ProtectedWindow == False):
+			self.Destroy()
+			self.SendBash("MSG_RECEIVED=Cancel") #Indiquera à PlayOnLinux bash qu'il faut arreter l'installation
+			#if(os.environ["POL_OS"] = "Mac"):
+			os.system("kill -9 -"+self.bash_pid+" 2> /dev/null")
+			#if(os.environ["POL_OS"] = "Linux"):
+			#	os.system("pkill -9 -P"+self.bash_pid+" 2> /dev/null")
+			
+			#time.sleep(0.3)
+			os.system("kill -9 "+self.bash_pid+" 2> /dev/null") # Plus bourrain, mais bien plus efficace
+			os.remove(self.file_id) # La on est plutôt pépère pour faire ça
+		else:
+			wx.MessageBox(_("You cannot close this window").format(os.environ["APPLICATION_TITLE"]),_("Error"))
+			
 	def CleanExit(self):
 		self.Destroy()
 		self.SendBash("MSG_RECEIVED=Cancel") #Indiquera à PlayOnLinux bash qu'il faut arreter l'installation
@@ -345,19 +379,21 @@ class POL_SetupFrame(wx.Frame): #fenêtre principale
 		self.i = 0
 		for game in self.games: 
 			self.file = Variables.playonlinux_rep+"/shortcuts/"+game
-			fichier = open(self.file,"r").read()
+			if(not os.path.isdir(self.file)):
+				fichier = open(self.file,"r").read()
 
-			if("POL_Wine " in fichier):
-				if(os.path.exists(Variables.playonlinux_rep+"/icones/32/"+game)):
-					self.file_icone = Variables.playonlinux_rep+"/icones/32/"+game
-				else:
-					self.file_icone = Variables.playonlinux_env+"/etc/playonlinux32.png"
-				self.bitmap = wx.Image(self.file_icone)
-				self.bitmap.Rescale(22,22,wx.IMAGE_QUALITY_HIGH)
-				self.bitmap = self.bitmap.ConvertToBitmap()
-				self.images.Add(self.bitmap)
-				self.MenuGames.AppendItem(self.root, game, self.i)
-				self.i = self.i+1
+				if("POL_Wine " in fichier):
+					if(os.path.exists(Variables.playonlinux_rep+"/icones/32/"+game)):
+						self.file_icone = Variables.playonlinux_rep+"/icones/32/"+game
+					else:
+						self.file_icone = Variables.playonlinux_env+"/etc/playonlinux32.png"
+					
+					self.bitmap = wx.Image(self.file_icone)
+					self.bitmap.Rescale(22,22,wx.IMAGE_QUALITY_HIGH)
+					self.bitmap = self.bitmap.ConvertToBitmap()
+					self.images.Add(self.bitmap)
+					self.MenuGames.AppendItem(self.root, game, self.i)
+					self.i = self.i+1
 
 
 	def add_menu_icons(self):
@@ -404,7 +440,7 @@ class POL_SetupFrame(wx.Frame): #fenêtre principale
 		self.FileDialog.SetDirectory(self.fichier[5].replace("\n",""))
 		self.FileDialog.ShowModal() 
 		if(self.FileDialog.GetPath() != ""):
-			self.champ.SetValue(self.FileDialog.GetPath().encode('utf-8'))
+			self.champ.SetValue(self.FileDialog.GetPath().encode("utf-8","replace"))
 	        self.FileDialog.Destroy()
    
 	def DownloadFile(self, url, localB):    #url = url a récupérer, localB le fichier où enregistrer la modification sans nom de fichier
@@ -516,6 +552,7 @@ class POL_SetupFrame(wx.Frame): #fenêtre principale
 								self.titre.Show()
 
 								self.space=self.fichier[2].count("\\n")+1
+								self.register_link = self.fichier[4]
 
 								self.login.Show()
 								self.loginbox.Show()
@@ -546,7 +583,7 @@ class POL_SetupFrame(wx.Frame): #fenêtre principale
 								self.DrawCancel()
 								self.DrawNext()
 								wx.EVT_BUTTON(self, wx.ID_FORWARD, self.release_bigchamp)
-																
+				
 							if(self.fichier[1] == "browse\n"):
 								self.DrawHeader()
 								self.texte.SetLabel(self.fichier[2].replace("\\n","\n"))
@@ -663,7 +700,7 @@ class POL_SetupFrame(wx.Frame): #fenêtre principale
 								self.DrawNext()
 								wx.EVT_BUTTON(self, wx.ID_FORWARD, self.release_checkboxes)	
 
-							if(self.fichier[1] == "attendre_signal\n" or self.fichier[1] == "pulsebar\n"):
+							if(self.fichier[1] == "attendre_signal\n" or self.fichier[1] == "pulsebar\n" or self.fichier[1] == "attendre_signal_b\n"):
 								self.DrawHeader()
 								self.timer_attendre = wx.Timer(self, 1)
 								self.texte.SetLabel(self.fichier[2].replace("\\n","\n"))
@@ -674,17 +711,24 @@ class POL_SetupFrame(wx.Frame): #fenêtre principale
 								
 								self.space=self.fichier[2].count("\\n")+1
 								self.gauge_space = self.space
-								if(self.fichier[1] == "attendre_signal\n"):
+								if(self.fichier[1] == "attendre_signal\n" or self.fichier[1] == "attendre_signal_b\n"):
 									self.gauge.Show()
 									self.gauge.SetPosition((70,95+self.space*16))
 								else :
 									self.pulsebar.Show()
 									self.pulsebar.SetPosition((70,95+self.space*16))
 
+								if(self.fichier[1] == "attendre_signal_b\n"):
+									self.WaitButton.Show()
+									self.WaitButton.SetLabel(self.fichier[4].replace("\n",""))
+									self.WaitButton.SetPosition((135,135+self.space*16))
+									self.Bind(wx.EVT_BUTTON, lambda event: self.RunCommand(event,self.fichier[5].replace("\n",""),self.fichier[6].replace("\n","")),self.WaitButton)
+									
 								self.DrawCancel()
 								self.DrawNext()
 								self.NextButton.Enable(False)
 
+									
 							if(self.fichier[1] == "download\n"):
 								self.DrawHeader()
 								self.texte.SetLabel(self.fichier[2].replace("\\n","\n"))
@@ -799,8 +843,11 @@ class POL_SetupFrame(wx.Frame): #fenêtre principale
 								#self.Mchamp.SetValue(open(self.fichier[4].replace("\n",""),"r").read())
 								
 								#
-								
-								self.texte_panel.SetLabel(open(self.fichier[4].replace("\n",""),"r").read())
+								try:
+									self.texte_panel.SetLabel(open(self.fichier[4].replace("\n",""),"r").read())
+								except:
+									self.texte_panel.SetLabel("E. file not found :"+self.fichier[4].replace("\n",""))
+									
 								self.texte_panel.Wrap(400)
 								self.texte_panel.Show()
 								
@@ -846,33 +893,13 @@ class POL_SetupFrame(wx.Frame): #fenêtre principale
 								
 								#self.titre.SetFont(self.fontText)
 								self.YesButton.Show()
-								self.NoButton.Show()
-
-							if(self.fichier[1] == "make_shortcut\n"):
-								self.DrawHeader()
-								self.texte.SetLabel(_("Create a shortcut :"))
-								self.texte.Show()
-								
-								#self.titre_header = wx.StaticText(self.header, -1, _("PlayOnMac Wizard"),pos=(5,5), size=(340,356))
-								#self.texte.SetFont(self.fontText)
-								#self.titre_header.SetFont(self.fontTitre)
-								self.titre_header.Show()
-								#self.titre = wx.StaticText(self.header, -1, _("Do you want a shortcut for ")+self.fichier[2].replace("\n","")+" ?",pos=(20,30), size=(340,356))
-								self.titre.SetLabel(_("Do you want a shortcut for ")+self.fichier[2].replace("\n","")+" ?")
-								self.titre.Show()
-								
-								self.desktop = wx.CheckBox(self.panel, -1, _("On your desktop"),pos=(25,105))
-								self.menu = wx.CheckBox(self.panel, -1, _("In your menu"),pos=(25,125))
-
-								#self.titre.SetFont(self.fontText)
-								self.DrawCancel()
-								self.DrawNext()
-								wx.EVT_BUTTON(self, wx.ID_FORWARD, self.release_icons)	
+								self.NoButton.Show()	
 					
 							if(self.fichier[1] == "free_presentation\n"):
 								self.MainPanel.Show()
 								self.titreP.SetLabel(self.fichier[2])
 								self.titreP.Wrap(280)
+								
 								self.texteP.SetLabel(self.fichier[3].replace("\\n","\n").decode("utf8"))
 								self.texteP.Wrap(360)
 								self.texteP.Show()
