@@ -1,8 +1,9 @@
 #!/usr/bin/env python
 # Copyright (C) 2007-2010 PlayOnLinux Team
+# Copyright (C) 2011 - Quentin PARIS
 
-import os, random, sys
-import wx
+import os, random, sys, string
+import wx, lib.playonlinux as playonlinux
 
 # Un ptit check
 try :
@@ -23,6 +24,7 @@ if (os.environ["POL_OS"] == "Mac"):
 	windows_add_playonmac = 1;
 	widget_borders = wx.SIMPLE_BORDER
 	os_name = "darwin"
+	os.environ["POL_WGET"] = "wget -4 -q"
 	
 # Variables PlayOnLinux
 if (os.environ["POL_OS"] == "Linux"):
@@ -32,8 +34,15 @@ if (os.environ["POL_OS"] == "Linux"):
 	windows_add_playonmac = 0;
 	widget_borders = wx.RAISED_BORDER
 	os_name = "linux"
+	if not os.path.exists("/proc/net/if_inet6"):
+		os.environ["POL_WGET"] = "wget -q"
+	else:
+		os.environ["POL_WGET"] = "wget -4 -q"
 
-if(os.environ["MACHTYPE"] == "x86_64-pc-linux-gnu"):
+archi = string.split(os.environ["MACHTYPE"],"-")
+archi = archi[0]
+
+if(archi == "x86_64" and os.environ["POL_OS"] == "Linux"):
 	os.environ["AMD64_COMPATIBLE"] = "True"
 else:
 	os.environ["AMD64_COMPATIBLE"] = "False"
@@ -42,13 +51,17 @@ else:
 os.environ["POL_USER_ROOT"] = os.environ["REPERTOIRE"]
 os.environ["TITRE"] = os.environ["APPLICATION_TITLE"]
 os.environ["SITE"] = "http://repository.playonlinux.com"
-os.environ["VERSION"] = "4.0.12"
+os.environ["VERSION"] = "4.1.1"
 os.environ["POL_ID"] = str(random.randint(1,100000000))
 os.environ["WINEPREFIX"] = os.environ["REPERTOIRE"]+"/wineprefix/default"
-os.environ["WINE_SITE"] = "http://www.playonlinux.com/wine/binaries/"
+os.environ["WINE_SITE"] = "http://www.playonlinux.com/wine/binaries"
+os.environ["GECKO_SITE"] = "http://www.playonlinux.com/wine/gecko"
 os.environ["OS_NAME"] = os_name 
 homedir = os.environ["HOME"]
 
+# Wine
+os.environ["WINEDLLOVERRIDES"] = "winemenubuilder.exe=d"
+
 # Si DYLD_LIBRARY_PATH n'existe pas, on la defini pour etre sur	
 try :
 	os.environ["DYLD_LIBRARY_PATH"]
@@ -82,8 +95,20 @@ playonlinux_rep = os.environ["REPERTOIRE"]
 version = os.environ["VERSION"]
 current_user = os.environ["USER"]
 
-# Je sais plus a quoi ca sert, mais ca sert
-os.environ["SHLVL"]="2"
+os.environ["WGETRC"] = os.environ["POL_USER_ROOT"]+"/configurations/wgetrc"
+
+		
+# Propagate kill signals
+#os.system("set -o monitor")
 
 # On fait le minimum avant de lancer l'interface
-os.system("bash "+playonlinux_env+"/bash/startup &")
+os.system("bash "+playonlinux_env+"/bash/startup")
+
+## Proxy settings
+if(playonlinux.GetSettings("PROXY_ENABLED") == "1"):
+	if(playonlinux.GetSettings("PROXY_URL") != ""):
+		if(playonlinux.GetSettings("PROXY_LOGIN") == ""):
+			http_proxy = "http://"+playonlinux.GetSettings("PROXY_URL")+":"+playonlinux.GetSettings("PROXY_PORT")
+		else:
+			http_proxy = "http://"+playonlinux.GetSettings("PROXY_LOGIN")+":"+playonlinux.GetSettings("PROXY_PASSWORD")+"@"+playonlinux.GetSettings("PROXY_URL")+":"+playonlinux.GetSettings("PROXY_PORT")
+		os.environ["http_proxy"] = http_proxy
