@@ -4,7 +4,29 @@
 # Copyright (C) 2007-2010 PlayOnLinux Team
 
 import Variables, os, string
+import shlex, pipes, wx
 
+def winpath(script, path):
+	#path=os.path.realpath(path)
+	if(path[0] != "/"):
+		path=os.environ["WorkingDirectory"]+"/"+path
+	path = os.path.realpath(path)
+	pref = getPrefix(script)
+	ver = GetSettings('VERSION',pref)
+	arch = GetSettings('ARCH',pref)
+	if(arch == ""):
+		arch="x86"
+	if(ver == ""):
+		return(os.popen("env WINEPREFIX='"+os.environ["POL_USER_ROOT"]+"/wineprefix/"+pref.encode("utf-8","replace")+"/' 'wine' winepath -w '"+path.encode("utf-8","replace")+"'").read().replace("\n","").replace("\r",""))	
+	else:
+		return(os.popen("env WINEPREFIX='"+os.environ["POL_USER_ROOT"]+"/wineprefix/"+pref.encode("utf-8","replace")+"/' '"+os.environ["POL_USER_ROOT"]+"/wine/"+Variables.os_name+"-"+arch+"/"+ver+"/bin/wine' winepath -w '"+path.encode("utf-8","replace")+"'").read().replace("\n","").replace("\r",""))
+
+def open_document(path, ext):
+	script = GetSettings(ext, '_EXT_')
+	if(script == ""):
+		wx.MessageBox(_("There is nothing installed to run .{0} files.").format(ext),os.environ["APPLICATION_TITLE"], wx.OK)
+	else:
+		os.system("bash "+Variables.playonlinux_env+"/bash/run_app \""+script+"\" \""+winpath(script,path)+"\"&")
 
 def GetWineVersion(game):
 	cfile = Variables.playonlinux_rep+"shortcuts/"+game
@@ -29,9 +51,11 @@ def GetWineVersion(game):
 def GetSettings(setting, prefix='_POL_'):
 	if(prefix == "_POL_"):
 		cfile = Variables.playonlinux_rep+"/playonlinux.cfg"
+	elif(prefix == "_EXT_"):
+		cfile = Variables.playonlinux_rep+"/extensions.cfg"
 	else:
 		cfile = Variables.playonlinux_rep+"/wineprefix/"+prefix+"/playonlinux.cfg"
-	
+
 	try:
 		fichier = open(cfile,"r").readlines()
 	except:
@@ -54,6 +78,8 @@ def GetSettings(setting, prefix='_POL_'):
 def SetSettings(setting, value, prefix='_POL_'):
 	if(prefix == "_POL_"):
 		cfile = Variables.playonlinux_rep+"/playonlinux.cfg"
+	elif(prefix == "_EXT_"):
+		cfile = Variables.playonlinux_rep+"/extensions.cfg"
 	else:
 		cfile = Variables.playonlinux_rep+"/wineprefix/"+prefix+"/playonlinux.cfg"
 
@@ -82,6 +108,8 @@ def SetSettings(setting, value, prefix='_POL_'):
 def DeleteSettings(setting, prefix='_POL_'):
 	if(prefix == "_POL_"):
 		cfile = Variables.playonlinux_rep+"/playonlinux.cfg"
+	elif(prefix == "_EXT_"):
+		cfile = Variables.playonlinux_rep+"/extensions.cfg"
 	else:
 		cfile = Variables.playonlinux_rep+"/wineprefix/"+prefix+"/playonlinux.cfg"
 
@@ -101,7 +129,8 @@ def DeleteSettings(setting, prefix='_POL_'):
 	while(i < len(line)): # On ecrit
 		fichier_write.write(line[i]+"\n")
 		i+=1
-								
+
+							
 def GetDebugState(game):
 	cfile = Variables.playonlinux_rep+"shortcuts/"+game
 	try:
@@ -198,11 +227,52 @@ def open_folder_prefix(software):
 			os.system("open "+AppDir)
 		else:
 			os.system("xdg-open "+AppDir)
-									
+
+def VersionLower(version1, version2):
+	version1 = string.split(version1, "-")
+	version2 = string.split(version2, "-")
+	
+	try:
+		if(version1[1] != ""):
+			dev1 = True
+	except:
+		dev1 = False
+	
+	try:
+		if(version1[2] != ""):
+			dev2 = True
+	except:
+		dev2 = False
+	
+	if(version1[0] == version2[0]):
+		if(dev1 == True or dev2 == False):
+			return False
+		else:
+			return True
+			
+	version1 = string.split(version1[0],".")
+	version2 = string.split(version2[0],".")
+	
+	if(version1[0] < version2[0]):
+		return True
+	elif(version1[0] == version2[0]):
+		if(version1[1] < version2[1]):
+			return True
+		elif(version1[1] == version2[1]):
+			if(version1[2] < version2[2]):
+				return True
+			else:
+				return False
+		else: 
+			return False
+	else:		
+		return False
+								
 def convertVersionToInt(version): # Code par MulX en Bash, adapte en python par Tinou
 	#rajouter pour les vesions de dev -> la version stable peut sortir
 	#les personnes qui utilise la version de dev sont quand même informé d'une MAJ
 	#ex 3.8.1 < 3.8.2-dev < 3.8.2
+	print "Deprecated !"
 	if("dev" in version or "beta" in version or "alpha" in version or "rc" in version):
 		version = string.split(version,"-")
 		version = version[0]
@@ -227,6 +297,9 @@ def convertVersionToInt(version): # Code par MulX en Bash, adapte en python par
 	return(versionDev + versionP1 + versionP2 + versionP3)
 	
 def getPrefix(shortcut): # Get prefix name from shortcut
+	if(os.path.isdir(os.environ["POL_USER_ROOT"]+"/shortcuts/"+shortcut)):
+		return ""
+		
 	fichier = open(os.environ["POL_USER_ROOT"]+"/shortcuts/"+shortcut,'r').read()
 	fichier = string.split(fichier,"\n")
 	i = 0
@@ -241,15 +314,39 @@ def getPrefix(shortcut): # Get prefix name from shortcut
 		prefix = string.split(prefix,"/")
 	
 		if(os.environ["POL_OS"] == "Mac"):
-			prefix = prefix[6]
+			index_of_dotPOL = prefix.index("PlayOnMac")
+			prefix = prefix[index_of_dotPOL + 2]
 		else:
-			prefix = prefix[5]
+			index_of_dotPOL = prefix.index(".PlayOnLinux")
+			prefix = prefix[index_of_dotPOL + 2]
 	except:
 		prefix = ""
 		
 	return prefix
 	
+
+def getArgs(shortcut): # Get prefix name from shortcut
+	if(os.path.isdir(os.environ["POL_USER_ROOT"]+"/shortcuts/"+shortcut)):
+		return ""
 	
+	fichier = open(os.environ["POL_USER_ROOT"]+"/shortcuts/"+shortcut,'r').read()
+	fichier = string.split(fichier,"\n")
+	i = 0
+	while(i < len(fichier)):
+		if("POL_Wine" in fichier[i]):
+			break
+		i += 1
+
+	try:
+		args = shlex.split(fichier[i])[2:-1]
+		#print args
+		args = " ".join([ pipes.quote(x) for x in args])
+		#print args
+	except:
+		args = ""
+
+	return args
+			
 def Get_versions(arch='x86'):
 	installed_versions = os.listdir(Variables.playonlinux_rep+"/wine/"+Variables.os_name+"-"+arch+"/")
 	installed_versions.sort(key=keynat)
@@ -284,4 +381,40 @@ def SetWinePrefix(game, prefix):
 	i = 0	
 	while(i < len(line)): # On ecrit
 		fichier_write.write(line[i]+"\n")
-		i+=1
\ No newline at end of file
+		i+=1
+	
+	
+def writeArgs(game, args):
+	cfile = Variables.playonlinux_rep+"shortcuts/"+game
+	fichier = open(cfile,"r").readlines()
+	i = 0
+	line = []
+	
+	while(i < len(fichier)): # On retire l'eventuel
+		fichier[i] = fichier[i].replace("\n","")
+		if("POL_Wine" not in fichier[i]):
+			line.append(fichier[i])
+		else:
+			try:
+				old_string = shlex.split(fichier[i])
+				new_string = shlex.split(str(args))
+				new_string = old_string[0:2] + new_string
+				new_string = " ".join([ pipes.quote(x) for x in new_string])
+
+				new_string = new_string+" $@"
+				line.append(new_string)
+			except:
+				line.append(fichier[i])
+		i += 1
+
+	fichier_write = open(cfile,"w")
+	i = 0	
+	while(i < len(line)): # On ecrit
+		fichier_write.write(line[i]+"\n")
+		i+=1
+			
+def POL_Open(arg):
+	if(os.environ["POL_OS"] == "Mac"):
+		os.system("open \""+arg+"\"&")
+	else:
+		os.system("xdg-open \""+arg+"\"&")
