@@ -18,7 +18,7 @@
 # 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA. 
 encoding = 'utf-8'
 
-import os, getopt, sys, urllib, signal, string, time, webbrowser, gettext, locale, sys, shutil
+import os, getopt, sys, urllib, signal, string, time, webbrowser, gettext, locale, sys, shutil, subprocess
 #locale.setlocale(locale.CODESET,'fr_FR.utf8')
 
 #try:
@@ -27,12 +27,16 @@ import os, getopt, sys, urllib, signal, string, time, webbrowser, gettext, local
 #	os.environ["LANG"] = "en_US.utf-8"
 #locale.setlocale(locale.LC_ALL, '.utf-8')
 
-import wx
+if(os.environ["POL_OS"] == "Linux"):
+	import wxversion
+	wxversion.ensureMinimal('2.8')
 	
+import wx
 import lib.Variables as Variables, lib.lng as lng
 import lib.playonlinux as playonlinux
-import guiv3 as gui, install, options, wine_versions as wver, sp, configure, threading
+import guiv3 as gui, install, options, wine_versions as wver, sp, configure, threading, debug
 import irc as ircgui
+
 class POLWeb(threading.Thread):
 	def __init__(self):
 		threading.Thread.__init__(self)
@@ -55,7 +59,7 @@ class POLWeb(threading.Thread):
 			fichier_online="version_mac"
 		else:
 			fichier_online="version2"
-		return os.popen('wget -4 -q "'+os.environ["SITE"]+'/'+fichier_online+'.php?v='+os.environ["VERSION"]+'" -T 30 -O-','r').read()
+		return os.popen(os.environ["POL_WGET"]+' "'+os.environ["SITE"]+'/'+fichier_online+'.php?v='+os.environ["VERSION"]+'" -T 30 -O-','r').read()
 	
 	def real_check(self):
 		self.WebVersion = self.LastVersion()
@@ -66,7 +70,7 @@ class POLWeb(threading.Thread):
 			self.sendToStatusBar(_("Refreshing {0}").format(os.environ["APPLICATION_TITLE"]), True)
 			os.system("bash \""+Variables.playonlinux_env+"/bash/pol_update_list\"")
 		
-			if(playonlinux.convertVersionToInt(os.environ["VERSION"]) < playonlinux.convertVersionToInt(self.WebVersion)):
+			if(playonlinux.VersionLower(os.environ["VERSION"],self.WebVersion)):
 				self.sendToStatusBar(_('An updated version of {0} is available').format(os.environ["APPLICATION_TITLE"])+" ("+self.WebVersion+")",False)
 				self.sendAlert(_('An updated version of {0} is available').format(os.environ["APPLICATION_TITLE"])+" ("+self.WebVersion+")")
 			else:
@@ -91,7 +95,9 @@ class MainWindow(wx.Frame):
 			
 	wx.Frame.__init__(self, parent, 1000, title, size = (515,450))
 	self.SetMinSize((300,300))
+	
 
+		
 	try:
 		self.windowWidth = int(playonlinux.GetSettings("MAINWINDOW_WIDTH"))
 		self.windowHeight = int(playonlinux.GetSettings("MAINWINDOW_HEIGHT"))
@@ -139,13 +145,18 @@ class MainWindow(wx.Frame):
 	self.oldimg = ""
 	
 	self.filemenu = wx.Menu()
+	if(os.environ["POL_OS"] == "Mac"):
+		prefItem = self.filemenu.Append(wx.ID_PREFERENCES, text = "&Preferences")
+		self.Bind(wx.EVT_MENU, self.Options, prefItem)
+		
 	self.filemenu.Append(wx.ID_OPEN, _("Run"))
 	self.filemenu.Append(wx.ID_ADD, _("Install"))
 	self.filemenu.Append(wx.ID_DELETE, _("Remove"))
 	self.filemenu.AppendSeparator()
 	self.filemenu.Append(216, _("Donate"))
 	self.filemenu.Append(wx.ID_EXIT, _("Exit"))
-
+	
+	
 	self.displaymenu = wx.Menu()
 	self.icon16 = self.displaymenu.AppendRadioItem(501, _("Small icons"))
 	self.icon24 = self.displaymenu.AppendRadioItem(502, _("Medium icons"))
@@ -171,6 +182,12 @@ class MainWindow(wx.Frame):
 	#self.wineprefix_item.SetBitmap(wx.Bitmap(Variables.playonlinux_env+"/resources/images/menu/prefix-manager.png"))
 	#self.expertmenu.AppendItem(self.wineprefix_item)
 
+	if(os.environ["POL_OS"] == "Mac"):
+		self.expertmenu.AppendSeparator()
+		self.pccd_item = wx.MenuItem(self.expertmenu, 113, _("Read a PC CD-Rom"))
+		self.pccd_item.SetBitmap(wx.Bitmap(Variables.playonlinux_env+"/resources/images/menu/cdrom.png"))
+		self.expertmenu.AppendItem(self.pccd_item)
+		
 	self.expertmenu.AppendSeparator()
 
 	self.run_item = wx.MenuItem(self.expertmenu, 108, _("Run a local script"))
@@ -195,7 +212,7 @@ class MainWindow(wx.Frame):
 	self.chat_item.SetBitmap(wx.Bitmap(Variables.playonlinux_env+"/resources/images/menu/people.png"))
 	self.expertmenu.AppendItem(self.chat_item)
 		
-	self.bug_item = wx.MenuItem(self.expertmenu, 110, _("Report a bug"))
+	self.bug_item = wx.MenuItem(self.expertmenu, 110, _("{0} debugger").format(os.environ["APPLICATION_TITLE"]))
 	self.bug_item.SetBitmap(wx.Bitmap(Variables.playonlinux_env+"/resources/images/menu/bug.png"))
 	self.expertmenu.AppendItem(self.bug_item)
 	
@@ -210,6 +227,10 @@ class MainWindow(wx.Frame):
 	self.option_item.SetBitmap(wx.Bitmap(Variables.playonlinux_env+"/etc/onglet/internet-web-browser.png"))
 	self.optionmenu.AppendItem(self.option_item)
 
+	self.option_item = wx.MenuItem(self.expertmenu, 212, _("File associations"))
+	self.option_item.SetBitmap(wx.Bitmap(Variables.playonlinux_env+"/resources/images/menu/extensions.png"))
+	self.optionmenu.AppendItem(self.option_item)
+
 	#self.option_item = wx.MenuItem(self.expertmenu, 212, _("Environment"))
 	#self.option_item.SetBitmap(wx.Bitmap(Variables.playonlinux_env+"/etc/onglet/user-desktop.png"))
 	#self.optionmenu.AppendItem(self.option_item)
@@ -301,7 +322,7 @@ class MainWindow(wx.Frame):
 	self.toolbar.AddSeparator()
 	self.toolbar.AddLabelTool(121, _("Configure"), wx.Bitmap(Variables.playonlinux_env+"/resources/images/toolbar/configure.png"))
 	self.toolbar.AddLabelTool(122, _("Shortcut"), wx.Bitmap(Variables.playonlinux_env+"/resources/images/toolbar/package.png"))
-	self.toolbar.AddLabelTool(123, _("Messenger"), wx.Bitmap(Variables.playonlinux_env+"/resources/images/toolbar/messenger.png"))
+	#self.toolbar.AddLabelTool(123, _("Messenger"), wx.Bitmap(Variables.playonlinux_env+"/resources/images/toolbar/messenger.png"))
 
 	#self.toolbar.DoMenuUpdate(self.toolbar)
 	self.toolbar.Realize()
@@ -326,6 +347,7 @@ class MainWindow(wx.Frame):
 	wx.EVT_MENU(self, 110,  self.BugReport)
 	wx.EVT_MENU(self, 111,  self.OpenIrc)
 	wx.EVT_MENU(self, 112,  self.POLOnline)
+	wx.EVT_MENU(self, 113,  self.PCCd)
 	
 	wx.EVT_MENU(self, 115,  self.killall)
 	wx.EVT_MENU(self, 121,  self.Configure)
@@ -360,6 +382,8 @@ class MainWindow(wx.Frame):
 	wx.EVT_MENU(self, 233, self.ChangeIcon)
 	wx.EVT_MENU(self, 234, self.UninstallGame)
 	wx.EVT_MENU(self, 235, self.RKill)
+	wx.EVT_MENU(self, 236, self.ReadMe)
+	
 	#self.sb.Hide()
 
   def StatusRead(self):
@@ -393,6 +417,10 @@ class MainWindow(wx.Frame):
 	self.GotoAppDir.SetBitmap(wx.Bitmap(Variables.playonlinux_env+"/resources/images/menu/folder-wine.png"))
 	self.GameListPopUpMenu.AppendItem(self.GotoAppDir)
 
+	self.ChangeIcon = wx.MenuItem(self.GameListPopUpMenu, 236, _("Read the manual"))
+	self.ChangeIcon.SetBitmap(wx.Bitmap(Variables.playonlinux_env+"/resources/images/menu/manual.png"))
+	self.GameListPopUpMenu.AppendItem(self.ChangeIcon)
+	
 	self.ChangeIcon = wx.MenuItem(self.GameListPopUpMenu, 233, _("Set the icon"))
 	self.ChangeIcon.SetBitmap(wx.Bitmap(Variables.playonlinux_env+"/resources/images/menu/change_icon.png"))
 	self.GameListPopUpMenu.AppendItem(self.ChangeIcon)
@@ -417,11 +445,18 @@ class MainWindow(wx.Frame):
   def RKill(self, event):
         self.RConfigure(_("KillApp"), "nothing")
 
+  def ReadMe(self, event):
+	game_exec = self.list_game.GetItemText(self.list_game.GetSelection()).encode("utf-8","replace")
+	if(os.path.exists(os.environ["POL_USER_ROOT"]+"/configurations/manuals/"+game_exec)):
+		playonlinux.POL_Open(os.environ["POL_USER_ROOT"]+"/configurations/manuals/"+game_exec)
+	else:
+		wx.MessageBox(_("No manual found for {0}").format(game_exec), os.environ["APPLICATION_TITLE"])
+	
   def RRegistryEditor(self, event):
         self.RConfigure(_("Registry Editor"), "nothing")
 
   def run_plugin(self, event):
-	game_exec = self.list_game.GetItemText(self.list_game.GetSelection()).encode("utf-8")
+	game_exec = self.list_game.GetItemText(self.list_game.GetSelection()).encode("utf-8","replace")
 	plugin=self.plugin_list[event.GetId()-300]
 	try :
 		os.system("bash \""+Variables.playonlinux_rep+"/plugins/"+plugin+"/scripts/menu\" \""+game_exec+"\"&")
@@ -455,7 +490,7 @@ class MainWindow(wx.Frame):
 	self.irc.Show(True)
 		
   def GoToAppDir(self, event):
-		self.game_exec = self.list_game.GetItemText(self.list_game.GetSelection()).encode("utf-8")
+		self.game_exec = self.list_game.GetItemText(self.list_game.GetSelection()).encode("utf-8","replace")
 		playonlinux.open_folder(self.game_exec)
 		
   def ChangeIcon(self, event):
@@ -477,7 +512,7 @@ class MainWindow(wx.Frame):
 			#Pop-up menu for game list: ending
 
   def Select(self, event):
-	game_exec = self.list_game.GetItemText(self.list_game.GetSelection()).encode("utf-8")
+	game_exec = self.list_game.GetItemText(self.list_game.GetSelection()).encode("utf-8","replace")
 	self.read = open(Variables.playonlinux_rep+"shortcuts/"+game_exec,"r").readlines()
 	self.i = 0;
 	self.wine_present = False;
@@ -508,25 +543,25 @@ class MainWindow(wx.Frame):
 	 else:
 		self.iconFolder = "full_size";
 	 for game in self.games: #METTRE EN 32x32
-		if(os.path.exists(Variables.playonlinux_rep+"/icones/"+self.iconFolder+"/"+game)):
-			file_icone = Variables.playonlinux_rep+"/icones/"+self.iconFolder+"/"+game
-		else:
-			file_icone = Variables.playonlinux_env+"/etc/playonlinux.png"
+		if(not os.path.isdir(Variables.playonlinux_rep+"/shortcuts/"+game)):
+			if(os.path.exists(Variables.playonlinux_rep+"/icones/"+self.iconFolder+"/"+game)):
+				file_icone = Variables.playonlinux_rep+"/icones/"+self.iconFolder+"/"+game
+			else:
+				file_icone = Variables.playonlinux_env+"/etc/playonlinux.png"
 
-		try:
-			self.bitmap = wx.Image(file_icone)
-			self.bitmap.Rescale(self.iconSize,self.iconSize,wx.IMAGE_QUALITY_HIGH)
-			self.bitmap = self.bitmap.ConvertToBitmap()
-			self.images.Add(self.bitmap)
-		except:
-			pass
-		item = self.list_game.AppendItem(root, game, self.i)
-		self.i += 1
-	
+			try:
+				self.bitmap = wx.Image(file_icone)
+				self.bitmap.Rescale(self.iconSize,self.iconSize,wx.IMAGE_QUALITY_HIGH)
+				self.bitmap = self.bitmap.ConvertToBitmap()
+				self.images.Add(self.bitmap)
+			except:
+				pass
+			item = self.list_game.AppendItem(root, game, self.i)
+			self.i += 1	
 
   def RConfigure(self, function_to_run, firstargument):
 		"""Starts polconfigurator remotely."""
-		game_exec = self.list_game.GetItemText(self.list_game.GetSelection()).encode("utf-8")
+		game_exec = self.list_game.GetItemText(self.list_game.GetSelection()).encode("utf-8","replace")
 		if(game_exec != ""):
 			os.system("bash \""+Variables.playonlinux_env+"/bash/polconfigurator\" \""+game_exec+"\" \""+function_to_run+"\" \""+firstargument+"\"&")
 	
@@ -534,12 +569,16 @@ class MainWindow(wx.Frame):
 	
   def Options(self, event):
     onglet=event.GetId()
-    if(onglet == 211):
-    	self.optionFrame = options.MainWindow(self, -1, _("{0} settings").format(os.environ["APPLICATION_TITLE"]), 2)
-    if(onglet == 214):
-    	self.optionFrame = options.MainWindow(self, -1, _("{0} settings").format(os.environ["APPLICATION_TITLE"]), 1)
-    self.optionFrame.Center(wx.BOTH)
-    self.optionFrame.Show(True)
+    try:
+		self.optionFrame.SetFocus()
+    except:
+		self.optionFrame = options.MainWindow(self, -1, _("{0} settings").format(os.environ["APPLICATION_TITLE"]), 2)
+		if(onglet == 211):
+			self.optionFrame = options.MainWindow(self, -1, _("{0} settings").format(os.environ["APPLICATION_TITLE"]), 0)
+		if(onglet == 214):
+			self.optionFrame = options.MainWindow(self, -1, _("{0} settings").format(os.environ["APPLICATION_TITLE"]), 1)
+		self.optionFrame.Center(wx.BOTH)
+		self.optionFrame.Show(True)
 
   def killall(self, event):
     os.system("bash \""+Variables.playonlinux_env+"/bash/killall\"&")
@@ -548,34 +587,52 @@ class MainWindow(wx.Frame):
     os.system("bash \""+Variables.playonlinux_env+"/bash/expert/Executer\"&")
 
   def BugReport(self, event):
-    os.system("bash \""+Variables.playonlinux_env+"/bash/bug_report\"&")
+	try:
+		self.debugFrame.Show()
+		self.debugFrame.SetFocus()
+	except:
+		self.debugFrame = debug.MainWindow(None, -1, _("{0} debugger").format(os.environ["APPLICATION_TITLE"]))
+		self.debugFrame.Center(wx.BOTH)
+		self.debugFrame.Show()
+		
 
   def POLOnline(self, event):
     os.system("bash \""+Variables.playonlinux_env+"/bash/playonlinux_online\" &")
 
+  def PCCd(self, event):
+    os.system("bash \""+Variables.playonlinux_env+"/bash/read_pc_cd\" &")
+
   def PolShell(self, event):
     #Variables.run_x_server()
     os.system("bash \""+Variables.playonlinux_env+"/bash/expert/PolShell\"&")
 
   def Configure(self, event):
-	game_exec = self.list_game.GetItemText(self.list_game.GetSelection()).encode("utf-8")
-	if(game_exec == ""):
-		configureFrame = configure.MainWindow(None, -1, _("{0} configuration").format(os.environ["APPLICATION_TITLE"]),"default",True)
-	else:
-		configureFrame = configure.MainWindow(None, -1, _("{0} configuration").format(os.environ["APPLICATION_TITLE"]),game_exec,False)
-		#self.SetTopWindow(installFrame)
-	configureFrame.Center(wx.BOTH)
-	configureFrame.Show(True)
+	game_exec = self.list_game.GetItemText(self.list_game.GetSelection()).encode("utf-8","replace")
+	try:
+		self.configureFrame.Show(True)
+		self.configureFrame.SetFocus()
+		if(game_exec != ""):
+			self.configureFrame.change_program(game_exec,False)
+			
+	except:
+		if(game_exec == ""):
+			self.configureFrame = configure.MainWindow(self, -1, _("{0} configuration").format(os.environ["APPLICATION_TITLE"]),"default",True)
+		else:
+			self.configureFrame = configure.MainWindow(self, -1, _("{0} configuration").format(os.environ["APPLICATION_TITLE"]),game_exec.decode("utf-8","replace"),False)
+	
+		
+		self.configureFrame.Center(wx.BOTH)
+		self.configureFrame.Show(True)
 
     #os.system("bash \""+Variables.playonlinux_env+"/bash/polconfigurator\" \""+game_exec+"\"&")
 
   def Package(self, event):
     game_exec = self.list_game.GetItemText(self.list_game.GetSelection())
-    os.system("bash \""+Variables.playonlinux_env+"/bash/make_shortcut\" \""+game_exec.encode("utf-8")+"\"&")
+    os.system("bash \""+Variables.playonlinux_env+"/bash/make_shortcut\" \""+game_exec.encode("utf-8","replace")+"\"&")
 
   def UninstallGame(self, event):
     game_exec = self.list_game.GetItemText(self.list_game.GetSelection())
-    os.system("bash \""+Variables.playonlinux_env+"/bash/uninstall\" \""+game_exec.encode("utf-8")+"\"&")
+    os.system("bash \""+Variables.playonlinux_env+"/bash/uninstall\" \""+game_exec.encode("utf-8","replace")+"\"&")
 
 
   def AutoReload(self, event):
@@ -590,7 +647,7 @@ class MainWindow(wx.Frame):
 		message = open(fichier_index,'r').read()
 	message = string.split(message, "\n")
 	if(message[0] == "Open"):
-		self.frame = gui.POL_SetupFrame(os.environ["APPLICATION_TITLE"],message[1].replace("\n",""),message[2].replace("\n",""),message[3].replace("\n",""),message[4].replace("\n",""))
+		self.frame = gui.POL_SetupFrame(os.environ["APPLICATION_TITLE"],message[1].replace("\n",""),message[2].replace("\n",""),message[3].replace("\n",""),message[4].replace("\n",""),message[5].replace("\n",""))
 		self.frame.Center(wx.BOTH)
 		self.frame.Show(True)
 		open(fichier_index,'w').write("Wait")
@@ -607,26 +664,47 @@ class MainWindow(wx.Frame):
    
 
   def InstallMenu(self, event):
-    installFrame = install.InstallWindow(self, -1, _('{0} install menu').format(os.environ["APPLICATION_TITLE"]))
+    try:
+    	self.installFrame.Show(True)
+    	self.installFrame.SetFocus()
+    except:
+    	self.installFrame = install.InstallWindow(self, -1, _('{0} install menu').format(os.environ["APPLICATION_TITLE"]))
     #self.SetTopWindow(installFrame)
-    installFrame.Center(wx.BOTH)
-    installFrame.Show(True)
+    	self.installFrame.Center(wx.BOTH)
+    	self.installFrame.Show(True)
 	
   def WineVersion(self, event):
-    wversion = wver.MainWindow(None, -1, _('{0} wine versions manager').format(os.environ["APPLICATION_TITLE"]))
-    wversion.Center(wx.BOTH)
-    wversion.Show(True)
+    try:
+    	self.wversion.Show()
+    	self.wversion.SetFocus()
+    except:
+    	self.wversion = wver.MainWindow(None, -1, _('{0} wine versions manager').format(os.environ["APPLICATION_TITLE"]))
+    	self.wversion.Center(wx.BOTH)
+    	self.wversion.Show(True)
 	#os.system("bash \""+Variables.playonlinux_env+"/bash/wineversion\"&")
 
   def Run(self, event):
-    game_exec = self.list_game.GetItemText(self.list_game.GetSelection()).encode("utf-8")
-    if(game_exec != ""):
-		os.system("bash "+Variables.playonlinux_env+"/bash/run_app \""+game_exec+"\"&")
-		#os.system("cd \""+Variables.playonlinux_rep+"/shortcuts/\"  && bash \""+game_exec+"\"&")
+    game_exec = self.list_game.GetItemText(self.list_game.GetSelection()).encode("utf-8","replace")
+    game_prefix = playonlinux.getPrefix(game_exec)
+    if(os.path.exists(os.environ["POL_USER_ROOT"]+"/wineprefix/"+game_prefix)):
+		if(game_exec != ""):
+			if(playonlinux.GetDebugState(game_exec)):
+				try:
+					self.debugFrame.analyseReal(0, game_prefix)
+					self.debugFrame.Show()
+					self.debugFrame.SetFocus()
+				except:
+					self.debugFrame = debug.MainWindow(None, -1, _("{0} debugger").format(os.environ["APPLICATION_TITLE"]),game_prefix,0)
+					self.debugFrame.Center(wx.BOTH)
+					self.debugFrame.Show()
+			
+			os.system("bash "+Variables.playonlinux_env+"/bash/run_app \""+game_exec+"\"&")
+    else:
+		wx.MessageBox(_("The virtual drive associated with {0} ({1}) does no longer exists.").format(game_exec, game_prefix), os.environ["APPLICATION_TITLE"])
 
 
   def ClosePol(self, event):
-    if(wx.YES == wx.MessageBox(_('Are you sure you want to close all {0} Windows?').format(os.environ["APPLICATION_TITLE"]).decode("utf-8"), style=wx.YES_NO | wx.ICON_QUESTION)):
+    if(wx.YES == wx.MessageBox(_('Are you sure you want to close all {0} Windows?').format(os.environ["APPLICATION_TITLE"]).decode("utf-8","replace"),os.environ["APPLICATION_TITLE"], style=wx.YES_NO | wx.ICON_QUESTION)):
 		os.remove(Variables.playonlinux_rep+"/configurations/guis/index_"+os.environ["POL_ID"])
 		self.SizeToSave = self.GetSize();
 		self.PositionToSave = self.GetPosition();
@@ -647,7 +725,7 @@ class MainWindow(wx.Frame):
     self.aboutBox.SetName(os.environ["APPLICATION_TITLE"])
     self.aboutBox.SetVersion(Variables.version)
     self.aboutBox.SetDescription(_("Run your Windows programs on "+os.environ["POL_OS"]+" !"))
-    self.aboutBox.SetCopyright(_("(C) PlayOnLinux and PlayOnMac team 2011\nUnder GPL licence version 3"))
+    self.aboutBox.SetCopyright(_("(C) PlayOnLinux and PlayOnMac team 2012\nUnder GPL licence version 3"))
     self.aboutBox.AddDeveloper(_("Developer and Website: ")+"Tinou (Pâris Quentin), MulX (Petit Aymeric)")
     self.aboutBox.AddDeveloper(_("Scriptors: ")+"GNU_Raziel")
     self.aboutBox.AddDeveloper(_("Packager: ")+"MulX (Petit Aymeric), Tinou (Pâris Quentin)")
@@ -667,20 +745,17 @@ class PlayOnLinuxApp(wx.App):
 		lng.iLang()
 		close = False
 		exe_present = False
-		if(os.popen("id -u").read() == "0"):
-			wx.MessageBox(_("{0} is not supposed to be run as root. Sorry").format(os.environ["APPLICATION_TITLE"]))
-			sys.exit()
-			
 		
-		for f in  sys.argv[1:]:
-			
+		self.systemCheck()
+				
+		for f in  sys.argv[1:]:		
 			self.MacOpenFile(f)
 			if(".exe" in f or ".EXE" in f):
 				exe_present = True
 			close = True
 			
 		if(close == True and exe_present == False):
-			sys.exit()
+			os._exit(0)
 			
 		self.SetClassName(os.environ["APPLICATION_TITLE"])
 		self.SetAppName(os.environ["APPLICATION_TITLE"])
@@ -693,6 +768,83 @@ class PlayOnLinuxApp(wx.App):
 		
 		return True
 	
+	def singleCheck(self, package, fatal=True):
+		devnull = open('/dev/null', 'wb')
+		try:
+			returncode=subprocess.call(["which",package],stdout=devnull)
+		except:
+			returncode=255
+		
+		if(fatal == True):
+			message = "You need to install it to continue"
+		else:
+			message = "You should install it to use {0}"
+			
+		if(returncode != 0):
+			wx.MessageBox(_("{0} cannot find {1}.\n\n"+message).format(os.environ["APPLICATION_TITLE"],package),_("Error"))
+			if(fatal == True):
+				os._exit(1)
+			
+	def systemCheck(self):
+		#### Root uid check
+		if(os.popen("id -u").read() == "0\n" or os.popen("id -u").read() == "0"):
+			wx.MessageBox(_("{0} is not supposed to be run as root. Sorry").format(os.environ["APPLICATION_TITLE"]),_("Error"))
+			os._exit(1)			
+		
+		#### 32 bits OpenGL check
+		try:
+			returncode=subprocess.call([os.environ["PLAYONLINUX"]+"/bash/check_gl","x86"])
+		except:
+			returncode=255
+		if(os.environ["POL_OS"] == "Linux" and returncode != 0):
+			wx.MessageBox(_("{0} is unable to find 32bits OpenGL libraries.\n\nYou might encounter problem with your games").format(os.environ["APPLICATION_TITLE"]),_("Error"))
+		
+		#### 64 bits OpenGL check
+		if(os.environ["AMD64_COMPATIBLE"] == "True"):
+			try:
+				returncode=subprocess.call([os.environ["PLAYONLINUX"]+"/bash/check_gl","amd64"])
+			except:
+				returncode=255
+		if(os.environ["AMD64_COMPATIBLE"] == "True" and os.environ["POL_OS"] == "Linux" and returncode != 0):
+			wx.MessageBox(_("{0} is unable to find 64bits OpenGL libraries.\n\nYou might encounter problem with your games").format(os.environ["APPLICATION_TITLE"]),_("Error"))
+
+		#### Filesystem check
+		if(os.environ["POL_OS"] == "Linux"):
+			try:
+				returncode=subprocess.call([os.environ["PLAYONLINUX"]+"/bash/check_fs"])
+			except:
+				returncode=255
+			if(os.environ["POL_OS"] == "Linux" and returncode != 0):
+				wx.MessageBox(_("Your filesystem might prevent {0} from running correctly.\n\nPlease open {0} in a terminal to get more details").format(os.environ["APPLICATION_TITLE"]),_("Error"))
+		
+		#### Optirun check
+		"""
+		try:
+			returncode=subprocess.call(["which","optirun"])
+		except:
+			returncode=255
+		
+		if(returncode == 0):
+			if(playonlinux.GetSettings("OPTIRUN_ASKED") == ""):
+				playonlinux.SetSettings("OPTIRUN_ASKED","TRUE")
+				if(wx.YES == wx.MessageBox(_('{0} has detected that optirun is installed on your system.\n\nDo you want {0} to be configured to use it?').format(os.environ["APPLICATION_TITLE"]).decode("utf-8","replace"), os.environ["APPLICATION_TITLE"],style=wx.YES_NO | wx.ICON_QUESTION)):
+					playonlinux.SetSettings("PRE_WINE","optirun")
+		"""
+					
+		#### Other import checks
+		self.singleCheck("tar")
+		self.singleCheck("cabextract")
+		self.singleCheck("convert")
+		self.singleCheck("wget")
+		self.singleCheck("gpg")
+		self.singleCheck("xterm",False)
+		self.singleCheck("gettext.sh",False)
+		self.singleCheck("icotool",False)
+		self.singleCheck("wrestool",False)
+		self.singleCheck("wine",False)
+		self.singleCheck("unzip",False)
+		self.singleCheck("7z",False)
+		
 	def BringWindowToFront(self):
 		        try: # it's possible for this event to come when the frame is closed
 		            self.GetTopWindow().Raise()
@@ -706,7 +858,7 @@ class PlayOnLinuxApp(wx.App):
 			content = open(filename,"r").readlines()
 			i = 0
 			while(i < len(content)):
-			#	wx.MessageBox(content[i], "PlayOnLinux", wx.OK)
+				#wx.MessageBox(content[i], "PlayOnLinux", wx.OK)
 			   	
 				if("Path=" in content[i]):
 					cd_app = content[i].replace("Path=","").replace("\n","")
@@ -720,18 +872,20 @@ class PlayOnLinuxApp(wx.App):
 			except:
 				pass
 		
-		if(file_extension == "exe" or file_extension == "EXE"):
+		elif(file_extension == "exe" or file_extension == "EXE"):
 			os.system("bash \"$PLAYONLINUX/bash/run_exe\" \""+filename+"\" &")
 		
-		if(file_extension == "pol" or file_extension == "POL"):
-			if(wx.YES == wx.MessageBox(_('Are you sure you want to  want to install {0} package?').format(filename).decode("utf-8"), style=wx.YES_NO | wx.ICON_QUESTION)):
+		elif(file_extension == "pol" or file_extension == "POL"):
+			if(wx.YES == wx.MessageBox(_('Are you sure you want to  want to install {0} package?').format(filename).decode("utf-8","replace"), os.environ["APPLICATION_TITLE"],style=wx.YES_NO | wx.ICON_QUESTION)):
 				os.system("bash \"$PLAYONLINUX/bash/playonlinux-pkg\" -i \""+filename+"\" &")
-	
+		else:
+			playonlinux.open_document(filename,file_extension.lower())
+
 	def MacOpenURL(self, url):
 		if(os.environ["POL_OS"] == "Mac" and "playonlinux://" in url):
-			wx.MessageBox("You are trying to open a script design for PlayOnLinux! It might not work as expected")
+			wx.MessageBox(_("You are trying to open a script design for {0}! It might not work as expected").format("PlayOnLinux"), os.environ["APPLICATION_TITLE"])
 		if(os.environ["POL_OS"] == "Linux" and "playonmac://" in url):
-			wx.MessageBox("You are trying to open a script design for PlayOnMac! It might not work as expected")
+			wx.MessageBox(_("You are trying to open a script design for {0}! It might not work as expected").format("PlayOnMac"), os.environ["APPLICATION_TITLE"])
 			
 		os.system("bash \"$PLAYONLINUX/bash/playonlinux-url_handler\" \""+url+"\" &")
 		
@@ -739,9 +893,7 @@ class PlayOnLinuxApp(wx.App):
 		#sys.exit()
 		self.BringWindowToFront()
 
-
 lng.Lang()
-#os.system("bash \""+os.environ["PLAYONLINUX"]+"/bash/startup\"")
 app = PlayOnLinuxApp(redirect=False)
 app.MainLoop()
 #sys.exit(0)
