@@ -20,7 +20,7 @@
 
 from asyncore import dispatcher
 import wxversion, os, getopt, sys, urllib, signal, socket, string
-import wx, time
+import wx, time, re
 import webbrowser, shutil
 import threading, time, codecs
 from select import select
@@ -28,6 +28,7 @@ from select import select
 
 import lib.Variables as Variables
 import lib.lng as lng
+import lib.playonlinux as playonlinux
 
 class getPlugins(threading.Thread):
   def __init__(self):
@@ -91,6 +92,8 @@ class Onglets(wx.Notebook):
   		self.images_onglets.Add(wx.Bitmap(Variables.playonlinux_env+"/etc/onglet/user-desktop.png"));
   		self.images_onglets.Add(wx.Bitmap(Variables.playonlinux_env+"/etc/onglet/application-x-executable.png"));
 		self.images_onglets.Add(wx.Bitmap(Variables.playonlinux_env+"/etc/onglet/package-x-generic.png"));
+		self.images_onglets.Add(wx.Bitmap(Variables.playonlinux_env+"/resources/images/menu/extensions.png"));
+		
    		self.SetImageList(self.images_onglets)
 
 	
@@ -115,21 +118,13 @@ class Onglets(wx.Notebook):
 		
 		proxy_settings = {}
 		
-		proxy_settings['PROXY_ENABLED'] = "0"
-		proxy_settings['PROXY_ADRESS'] = ""
-		proxy_settings["PROXY_PORT"] = "8080"
-		proxy_settings["PROXY_LOGIN"] = ""
-		proxy_settings["PROXY_PASS"] = ""
-		
-		if(os.path.exists(Variables.playonlinux_rep+"/configurations/options/proxy")):
-			proxy = open(Variables.playonlinux_rep+"/configurations/options/proxy","r").readlines()
-			self.i = 0
-			
-			while(self.i < len(proxy)):
-				line_parsed = string.split(proxy[self.i].replace("\n","").replace("\r",""),"=")
-				#print line_parsed[0] + " " + line_parsed[1]
-				proxy_settings[line_parsed[0]] = line_parsed[1]
-				self.i += 1
+		proxy_settings['PROXY_ENABLED'] = playonlinux.GetSettings("PROXY_ENABLED")
+		if(proxy_settings['PROXY_ENABLED'] == ""):
+			proxy_settings['PROXY_ENABLED'] = "0"
+		proxy_settings['PROXY_ADRESS'] = playonlinux.GetSettings("PROXY_URL")
+		proxy_settings["PROXY_PORT"] = playonlinux.GetSettings("PROXY_PORT")
+		proxy_settings["PROXY_LOGIN"] = playonlinux.GetSettings("PROXY_LOGIN")
+		proxy_settings["PROXY_PASS"] = playonlinux.GetSettings("PROXY_PASSWORD")
 		
 		self.ProxyCheck = wx.CheckBox(self.panelInternet, 120, _("Set a proxy"),pos=(10,30))
 		self.ProxyCheck.SetValue(int(proxy_settings['PROXY_ENABLED']))
@@ -192,7 +187,7 @@ class Onglets(wx.Notebook):
 		self.sizerPlugins = wx.BoxSizer(wx.VERTICAL) 
 		self.txtPlugin = wx.StaticText(self.panelPlugins, -1, _("Installed plugins"), size=wx.DefaultSize)
 		self.txtPlugin.SetFont(self.fontTitle)
-		self.pluginlist = wx.TreeCtrl(self.panelPlugins, 220, style=wx.RAISED_BORDER|wx.TR_HIDE_ROOT|wx.TR_FULL_ROW_HIGHLIGHT)		
+		self.pluginlist = wx.TreeCtrl(self.panelPlugins, 220, style=Variables.widget_borders|wx.TR_HIDE_ROOT|wx.TR_FULL_ROW_HIGHLIGHT)		
 		self.pluginlist.SetSpacing(0)
 
 		self.pluginImgList = wx.ImageList(16,16)
@@ -208,10 +203,10 @@ class Onglets(wx.Notebook):
 		
 		self.panelPlugins.SetSizer(self.sizerPlugins)
    		self.panelPlugins.SetAutoLayout(True)
-		self.AddPlugin = wx.Button(self.panels_buttons_plugins, wx.ID_ADD,  pos=(0,0))
-		self.DelPlugin = wx.Button(self.panels_buttons_plugins, wx.ID_REMOVE, pos=(100,0))
-		self.ConfigurePlugin = wx.Button(self.panels_buttons_plugins, 212, _("Configure"), pos=(0,38))	
-		self.EnablePlugin = wx.Button(self.panels_buttons_plugins, 213, _("Enable"), pos=(100,38))
+		self.AddPlugin = wx.Button(self.panels_buttons_plugins, wx.ID_ADD, _("Add"), pos=(0,0), size=(100,35))
+		self.DelPlugin = wx.Button(self.panels_buttons_plugins, wx.ID_REMOVE, _("Remove"), pos=(100,0), size=(100,35))
+		self.ConfigurePlugin = wx.Button(self.panels_buttons_plugins, 212, _("Configure"), pos=(0,38), size=(100,35))	
+		self.EnablePlugin = wx.Button(self.panels_buttons_plugins, 213, _("Enable"), pos=(100,38), size=(100,35))
 		self.txtPlugin = wx.StaticText(self.panels_buttons_plugins, -1, _("Choose a plugin"), size=(300,150), pos=(200,5))
 
 		self.LoadPlugins()
@@ -225,6 +220,76 @@ class Onglets(wx.Notebook):
 		wx.EVT_BUTTON(self, 212, self.setup_plug)
 		wx.EVT_BUTTON(self, wx.ID_REMOVE, self.delete_plug)
 		wx.EVT_BUTTON(self, wx.ID_ADD, self.add_plug)
+	
+	def generateExts(self):
+		self.list_ext.DeleteAllItems()
+		i = 0
+		self.exts = open(os.environ["POL_USER_ROOT"]+"/extensions.cfg").readlines()
+		self.exts.sort()
+		for line in self.exts:
+			line = line.replace("\n","")
+			line = string.split(line,"=")
+			liner = "Line %s" % i
+			self.list_ext.InsertStringItem(i, liner)
+			self.list_ext.SetStringItem(i, 0, line[0])
+			self.list_ext.SetStringItem(i, 1, line[1])
+			i += 1
+		self.app_installed_text.Hide()
+		self.app_installed.Hide()
+		self.delete_ext.Hide()
+		self.app_installed.SetValue("")
+		self.app_selected = -1
+	
+	def reditExt(self, event):
+		
+		playonlinux.SetSettings(self.ext_selected, self.app_installed.GetValue(),'_EXT_')
+		self.generateExts()
+		
+	def editExt(self, event):
+		self.app_installed_text.Show()
+		self.app_installed.Show()
+		self.delete_ext.Show()
+		
+		self.app_selected = string.split(self.exts[event.m_itemIndex],"=")[1]
+		self.ext_selected = string.split(self.exts[event.m_itemIndex],"=")[0]
+		
+		self.app_installed.SetValue(self.app_selected.replace("\n","").replace("\r",""))
+
+	def delExt(self, event):
+		playonlinux.DeleteSettings(self.ext_selected,'_EXT_')
+		self.generateExts()
+	
+	def newExt(self, event):
+		newext = wx.GetTextFromUser(_("What is the extension?"), os.environ["APPLICATION_TITLE"])
+		re.sub(r'\W+', '', newext)
+		playonlinux.SetSettings(newext, "",'_EXT_')
+		
+		self.generateExts()
+		
+	def Extensions(self, nom):
+		self.panelExt= wx.Panel(self, -1)
+		self.list_ext = wx.ListCtrl(self.panelExt, 500, size=(504,350), pos=(1,1), style=wx.LC_REPORT)
+		self.list_ext.InsertColumn(0, 'Extension')
+		self.list_ext.InsertColumn(1, 'Program associated', width=320)
+		
+		self.app_installed_text = wx.StaticText(self.panelExt, pos=(1,388), label=_("Assigned program"))
+		self.app_installed = wx.ComboBox(self.panelExt, 501, pos=(170,385),size=(200,25))
+		self.delete_ext = wx.Button(self.panelExt, 502, pos=(372,385+2*Variables.windows_add_playonmac), size=(100,25), label=_("Delete"))
+		
+		
+		self.add_ext = wx.Button(self.panelExt, 503, pos=(1,359), size=(100,25), label=_("New"))
+		
+		
+		self.app_installed_list = os.listdir(os.environ["POL_USER_ROOT"]+"/shortcuts/")
+		for i in self.app_installed_list:
+			self.app_installed.Append(i)
+			
+		self.generateExts()
+		self.AddPage(self.panelExt, nom, imageId=6)
+		wx.EVT_LIST_ITEM_SELECTED(self, 500, self.editExt)
+		wx.EVT_COMBOBOX(self, 501, self.reditExt)
+		wx.EVT_BUTTON(self, 502, self.delExt)
+		wx.EVT_BUTTON(self, 503, self.newExt)
 
 	def setup_plug(self, event):
 		self.current_plugin = self.pluginlist.GetItemText(self.pluginlist.GetSelection())
@@ -235,17 +300,17 @@ class Onglets(wx.Notebook):
 		self.FileDialog = wx.FileDialog(self)
 		self.FileDialog.SetDirectory("~")
 		self.FileDialog.SetWildcard("POL Packages (*.pol)|*.pol")
-        	self.FileDialog.ShowModal()
-        	if(self.FileDialog.GetPath() != ""):
-			if(wx.YES == wx.MessageBox(_("Are you sure you want to install: ").decode("utf-8")+self.FileDialog.GetPath()+"?", style=wx.YES_NO | wx.ICON_QUESTION)):
-	      			os.system("bash \""+Variables.playonlinux_env+"/playonlinux-pkg\" -i \""+self.FileDialog.GetPath().encode('utf-8')+"\"")
+        	result = self.FileDialog.ShowModal()
+        	if(result == wx.ID_OK and self.FileDialog.GetPath() != ""):
+			if(wx.YES == wx.MessageBox(_("Are you sure you want to install: ").decode("utf-8","replace")+self.FileDialog.GetPath()+"?",os.environ["APPLICATION_TITLE"] ,style=wx.YES_NO | wx.ICON_QUESTION)):
+	      			os.system("bash \""+Variables.playonlinux_env+"/playonlinux-pkg\" -i \""+self.FileDialog.GetPath().encode("utf-8","replace")+"\"")
 				self.LoadPlugins()
         	self.FileDialog.Destroy()
 
 	def delete_plug(self, event):
 		self.current_plugin = self.pluginlist.GetItemText(self.pluginlist.GetSelection())
 		self.plugin_path = Variables.playonlinux_rep+"/plugins/"+self.current_plugin
-   	        if(wx.YES == wx.MessageBox(_("Are you sure you want to delete: ").decode("utf-8")+self.current_plugin+"?", style=wx.YES_NO | wx.ICON_QUESTION)):
+   	        if(wx.YES == wx.MessageBox(_("Are you sure you want to delete: ").decode("utf-8","replace")+self.current_plugin+"?", os.environ["APPLICATION_TITLE"],style=wx.YES_NO | wx.ICON_QUESTION)):
 			shutil.rmtree(self.plugin_path)
 			self.LoadPlugins()
 	def disable(self, event):
@@ -307,12 +372,12 @@ class MainWindow(wx.Frame):
     self.SetIcon(wx.Icon(Variables.playonlinux_env+"/etc/playonlinux.png", wx.BITMAP_TYPE_ANY))
     self.panelFenp = wx.Panel(self, -1)
     self.panels_buttons = wx.Panel(self.panelFenp, -1)
-    self.Apply = wx.Button(self.panels_buttons, wx.ID_APPLY, _("Apply"), pos=(400,0))
-    self.Close = wx.Button(self.panels_buttons, wx.ID_CLOSE, _("Cancel"), pos=(305,0))
+    self.Apply = wx.Button(self.panels_buttons, wx.ID_APPLY, _("Apply"), pos=(400,0), size=(100,35))
+    self.Close = wx.Button(self.panels_buttons, wx.ID_CLOSE, _("Cancel"), pos=(295,0), size=(100,35))
     self.sizer = wx.BoxSizer(wx.VERTICAL)   
     self.onglets = Onglets(self.panelFenp)
 
-    self.sizer.Add(self.onglets, 10, wx.EXPAND|wx.ALL, 2)
+    self.sizer.Add(self.onglets, 12, wx.EXPAND|wx.ALL, 2)
     self.sizer.Add(self.panels_buttons, 1, wx.EXPAND|wx.ALL, 2)
 
     #self.onglets.General(_("General"))
@@ -320,6 +385,8 @@ class MainWindow(wx.Frame):
     #self.onglets.Wine(_("Environment"))
     #self.onglets.System(_("System"))
     self.onglets.Plugins(_("Plugins"))
+    self.onglets.Extensions(_("File associations"))
+
     try:
 		self.onglets.SetSelection(onglet)
     except:
@@ -334,16 +401,14 @@ class MainWindow(wx.Frame):
     self.Destroy()
 
   def apply_settings(self, event):
-    if(self.onglets.ProxyAdresse.GetValue().replace("http://","") and self.onglets.ProxyPort.GetValue()):
-	    self.chaine = "PROXY_ENABLED="+str(int(self.onglets.ProxyCheck.IsChecked()))+"\nPROXY_ADRESS="+self.onglets.ProxyAdresse.GetValue().replace("http://","")+"\n"+"PROXY_PORT="+self.onglets.ProxyPort.GetValue()+"\n"
-	    if(self.onglets.ProxyLogin.GetValue() and self.onglets.ProxyPass.GetValue()):
-		self.chaine += "PROXY_LOGIN="+self.onglets.ProxyLogin.GetValue()+"\n"+"PROXY_PASS="+self.onglets.ProxyPass.GetValue()+"\n"
-    else:
-	    self.chaine=""
+	playonlinux.SetSettings("PROXY_ENABLED",str(int(self.onglets.ProxyCheck.IsChecked())))
+	if(self.onglets.ProxyCheck.IsChecked()):
+		playonlinux.SetSettings("PROXY_URL",self.onglets.ProxyAdresse.GetValue().replace("http://",""))
+		playonlinux.SetSettings("PROXY_PORT",self.onglets.ProxyPort.GetValue())
+		playonlinux.SetSettings("PROXY_LOGIN",self.onglets.ProxyLogin.GetValue())
+		playonlinux.SetSettings("PROXY_PASSWORD",self.onglets.ProxyPass.GetValue())
+	
 
-	   
-    open(Variables.playonlinux_rep+"/configurations/options/proxy","w").write(self.chaine)
-
-    wx.MessageBox(_("You must restart PlayOnLinux for the changes to take effect."), "PlayOnLinux", wx.OK)
-    self.Destroy()
+	wx.MessageBox(_("You must restart {0} for the changes to take effect.").format(os.environ["APPLICATION_TITLE"]), os.environ["APPLICATION_TITLE"], wx.OK)
+	self.Destroy()
 
